options linesize=80 nocenter pagesize=66;
options formdlim=' ' nodate nonumber;

/* NOTE: 1987 SIPP data file does not contain the variable   */
/* CHAMP.  As decided by Lara Shore-Sheppard on Sept. 20,    */
/* 2004, CHAMP is set to 1 if either CHAMPUS or CHAMPVA is   */
/* equal to 1.                                               */ 

/* Note that the 1987 SIPP data has space for 32 months of   */
/* data, but only the first 28 month are used.               */

/* This program is run:                                         */
/* - after SIPP_families87.sas has created a family structure   */
/*   from the main SIPP data (dataset fam87.ssd01) and          */
/* - after kdisab87.sas has combined the TopicalModule6 data    */
/*   with that family structure data to create a Kid Disability */
/*   dataset (kdisab87.ssd01).                                  */


libname family '/export/files7/welfare/dec04';


/* Get Income & Program-Participation variables from 1987 SIPP data */
/* (these were NOT read when the family structure was created).     */

filename in1 PIPE 'gunzip -c /files2/ldshore/sipp/1987/da9600.gz';
/* filename in1 '/export/files7/welfare/sep04_a/da9600'; */

data more87;
 infile in1 lrecl=12573 recfm=f missover;
 input
@8	PPID		9.
@17	PPENTRY		2.
@19	PPPNUM 		3.
@98    (PPMIS1-PPMIS28) (1.)
@202	PNLWGT		12.
@214	FNLWT87		12.
@226	FNLWT88		12.
@1237	RACE		1.
@1238	ETHNCTY		2.
@2231	WDISAB		1.
@2392	(PPINC1-PPINC28)	(8.)
@2648	(PPEARN1-PPEARN28)	(7.)
/* The following 6 variables not currently read or used (they */
/* are Family income values, but family defined differently). */
/* @2872	(FFINC1-FFINC28)	(8.) */
/* @3128	(FFEARN1-FFEARN28)	(6.) */
/* @3320	(FFPROP1-FFPROP28)	(6.) */
/* @3512	(FFTRAN1-FFTRAN28)	(6.) */
/* @3704	(FFOTHR1-FFOTHR28)	(6.) */
/* @4920	(FFPOV1-FFPOV28)	(5.) */
/* Note: Variable WAVFLG does not exist in 1987 SIPP */
@5081	(ESR1-ESR28)		(1.)
@5257	(JOBID101-JOBID128)	(2.)
@5321	(JOBID201-JOBID228)	(2.)
@6665	(BUSID101-BUSID128)	(2.)
@6729	(BUSID201-BUSID228)	(2.)
@7753	G1SR1 2.
@7755	G1SR2 2.
@7757	G1SR3 2.
@7759	G1SR4 2.
@7761	G1SR5 2.
@7763	G1SR6 2.
@7765	G1SR7 2.
@7767	G1SR8 2.
@7769	G1SR9 2.
@7771	G1SR10 2.
@7773	(G1AM101-G1AM128)	(5.)
@7933	(G1AM201-G1AM228)	(5.)
@8093	(G1AM301-G1AM328)	(5.)
@8253	(G1AM401-G1AM428)	(5.)
@8413	(G1AM501-G1AM528)	(5.)
@8573	(G1AM601-G1AM628)	(5.)
@8733	(G1AM701-G1AM728)	(5.)
@8893	(G1AM801-G1AM828)	(5.)
@9053	(G1AM901-G1AM928)	(5.)
@9213	(G1AM1001-G1AM1028)	(5.)
@10845	(MCARE1-MCARE28)	(1.)
@10877	(MCAID1-MCAID28)	(1.)
@10941	(AFDC1-AFDC28)		(1.)
@10973	(FOODST1-FOODST28)	(1.)
@11005	(GASST1-GASST28)	(1.)
/* Note: CHAMP not available in 1987 SIPP */
@11197  (champu1-champu28)   (1.) /* CHAMPUS */
@11229  (champv1-champv28)   (1.) /* CHAMPVA */
@11261	(HIOWN1-HIOWN28)	(1.)
@11293	(HIOTH1-HIOTH28)	(1.)
@11325	(HIEMP1-HIEMP28)	(1.)
@12061	(G1IM101-G1IM128)	(1.)
@12093	(G1IM201-G1IM228)	(1.)
@12125	(G1IM301-G1IM328)	(1.)
@12157	(G1IM401-G1IM428)	(1.)
@12189	(G1IM501-G1IM528)	(1.)
@12221	(G1IM601-G1IM628)	(1.)
@12253	(G1IM701-G1IM728)	(1.)
@12285	(G1IM801-G1IM828)	(1.)
@12317	(G1IM901-G1IM928)	(1.)
@12349	(G1IM1001-G1IM1028)	(1.)
;

/* Set two race/ethnicity variables */
 black=(race = 2);
 hispanic=(14 <= ethncty <= 20);

/* Define a set of arrays and change one observation of 28 variables 
   into 28 observations of one variable */

 array ppmis{28} ppmis1-ppmis28;
 array x17{28} PPINC1-PPINC28;
 array x18{28} PPEARN1-PPEARN28;
 array x26{28} ESR1-ESR28;
 array x27{28} JOBID101-JOBID128;
 array x28{28} JOBID201-JOBID228;
 array x29{28} BUSID101-BUSID128;
 array x30{28} BUSID201-BUSID228;
 array x41{28} MCARE1-MCARE28;
 array x42{28} MCAID1-MCAID28;
 array x43{28} AFDC1-AFDC28;
 array x44{28} FOODST1-FOODST28;
 array x45{28} GASST1-GASST28;
/* array x46{28} CHAMP1-CHAMP28; */
 array x50{28} CHAMPU1-CHAMPU28;
 array x51{28} CHAMPV1-CHAMPV28;
 array x47{28} HIOWN1-HIOWN28;
 array x48{28} HIOTH1-HIOTH28;
 array x49{28} HIEMP1-HIEMP28;

 do mnum=1 to 28;
 PPINC=x17{mnum};
 PPEARN=x18{mnum};
 ESR=x26{mnum};
 JOBID1=x27{mnum};
 JOBID2=x28{mnum};
 BUSID1=x29{mnum};
 BUSID2=x30{mnum};
 MCARE=x41{mnum};
 MCAID=x42{mnum};
 AFDC=x43{mnum};
 FOODST=x44{mnum};
 GASST=x45{mnum};
/* CHAMP=x46{mnum}; */
 CHAMP=0;
 if x50{mnum} eq 1 or x51{mnum} eq 1 then CHAMP=1;
 HIOWN=x47{mnum};
 HIOTH=x48{mnum};
 HIEMP=x49{mnum};
/* Recode some variables */
 array fix_0_2{9} mcare mcaid afdc champ hiown
                  hioth hiemp foodst gasst;
 do tmp=1 to 9;
  if fix_0_2(tmp) eq 0 then fix_0_2(tmp)=.;
  if fix_0_2(tmp) eq 2 then fix_0_2(tmp)=0;
 end;
 drop tmp;
/* Compute related variables */
 mnotafdc=(mcaid=1 and afdc=0);
 priv=(hiown=1 or hioth=1 or hiemp=1 or champ=1);
 if esr in (1,2,3,4,5) then empl=1;
  else if esr ne . then empl=0;
  else empl=.;
 if esr eq 8 then nilf=1;
  else if esr ne . then nilf=0;
  else nilf=.;

 array G1SR{10} ;
 array GAM{10,28}
    G1AM101-G1AM128 G1AM201-G1AM228 G1AM301-G1AM328
    G1AM401-G1AM428 G1AM501-G1AM528 G1AM601-G1AM628
    G1AM701-G1AM728 G1AM801-G1AM828 G1AM901-G1AM928   
    G1AM1001-G1AM1028;   
 array GIM{10,28}
    G1IM101-G1IM128 G1IM201-G1IM228 G1IM301-G1IM328
    G1IM401-G1IM428 G1IM501-G1IM528 G1IM601-G1IM628
    G1IM701-G1IM728 G1IM801-G1IM828 G1IM901-G1IM928   
    G1IM1001-G1IM1028;  
/* Initialize values of receipt variables */
 ssirec=0; afdcrec=0; garec=0; othwrec=0;
 persafdc=0; genasst=0; othwelf=0;
/* Search all ten SourceOfIncome values for 4 specific sources */ 
 do i = 1 to 10;
   if G1SR{i} eq 3 then do;   /* supplemental security income */
     ssirec=1; ssiamt=GAM{i,mnum}; ssiimp=GIM{i,mnum};
   end;
   if G1SR{i} eq 20 then do;  /* AFDC income */
     afdcrec=1; persafdc=GAM{i,mnum}; afdcimp=GIM{i,mnum}; 
   end;
   if G1SR{i} eq 21 then do;  /* general assistance */
     garec=1; genasst=GAM{i,mnum}; gaimp=GIM{i,mnum};
   end;
   if G1SR{i} eq 24 then do;  /* other welfare */
     othwrec=1; othwelf=GAM{i,mnum}; othwimp=GIM{i,mnum};
   end;
 end;
/* Sum three of the amounts */
 allwel=persafdc+genasst+othwelf;

/* Create SUNIQUE just as Lara does */
 syear='87';
 id1='000000000';
 id1=ppid;
 id2='00';
 id2=ppentry;
 id3='000';
 id3=pppnum;
 sippid=id1||id2||id3;
 puid=sippid;
 sunique=syear||id1||id2||id3;

/* Keep only the variables needed for final dataset */
 keep sunique mnum pnlwgt fnlwt87 fnlwt88 race ethncty wdisab
   ppinc ppearn esr jobid1 jobid2 busid1 busid2
   mcare mcaid afdc foodst gasst champ hiown hioth hiemp
   black hispanic empl nilf
   ssirec ssiamt ssiimp afdcrec persafdc afdcimp
   garec genasst gaimp othwrec othwelf othwimp
   mnotafdc priv
   allwel ;

 if ppmis(mnum) eq 1 then output;
 end;
run;
proc sort; by sunique mnum;
run;

/* Get totals for income and welfare data for each family */
/* which includes reference person, spouse of reference   */
/* person, all children of reference person regardless of */
/* age, and RELAT=14 children (i.e., other relative of    */
/* reference person who has RefPerson as their Guardian). */
/* First, get family definition information for desired people */
data famly;
 set family.fam87;
 if relat in(1,2,3,14);
 if ppmis eq 1;
 keep sunique mnum ppid hhaddi famid;
/* Add family definition to income&welfare variables */
data famly2;
 merge more87(in=inc_wel) famly(in=fam); by sunique mnum;
 if inc_wel and fam;
 keep mnum ppid hhaddi famid ppinc ppearn allwel persafdc afdc;
proc sort; by mnum ppid hhaddi famid;
proc summary data=famly2;
 by mnum ppid hhaddi famid;
 var ppinc ppearn allwel persafdc afdc;
 output out=faminc
   sum(ppinc)=faminc
   sum(ppearn)=famwsal
   sum(allwel)=famwelf
   sum(persafdc)=famafdc
   sum(afdc)=anyafdc;
run;
proc datasets; delete famly2;
/* Add new family income and welfare variables to dataset */
proc sort data=famly; by mnum ppid hhaddi famid;
data famly;
 merge famly faminc; by mnum ppid hhaddi famid;
 keep sunique mnum faminc famwsal famwelf famafdc anyafdc;
run;
proc sort data=famly; by sunique mnum;
data more87;
 merge more87 famly; by sunique mnum;
 length mnum race ethncty wdisab
   esr jobid1 jobid2 busid1 busid2
   mcare mcaid afdc foodst gasst champ hiown hioth hiemp
   black hispanic empl nilf mnotafdc priv
   ssirec ssiimp afdcrec afdcimp garec gaimp othwrec othwimp
   anyafdc  3 ;
/* For months when a person is not part of a "family" (that is, */
/* a set of people with RELAT=1,2,3,14), set their "family"     */
/* values to be their individual values for those variables.    */
 if faminc  eq . then faminc =ppinc;
 if famwsal eq . then famwsal=ppearn;
 if famwelf eq . then famwelf=allwel;
 if famafdc eq . then famafdc=persafdc;
 if anyafdc eq . then anyafdc=afdc;
run;
proc datasets; delete famly faminc;
run;
title 'Means of Income and ProgramParticipation variables';
proc means;
run;


/* MERGE IN DATA FROM EXTERNAL FILES *********************************/

libname sipp  '~ldshore/disk2';
/*libname disab '~ldshore/disk2/disab';*/
/*libname immig '~ldshore/disk2/immig';*/
libname disab '';
libname immig '';
libname higrad '/files1/kopchik/kids_higrad';

/* Make list of people in Family file,               */
/* keeping only the variables needed for merges.     */
/* Note that the temorary dataset FAMGUYS is used as */
/* a start; the temporary dataset ADDVARS is created */
/* from it and has additional variables added to it  */
/* step-by-step as files are merged in.              */
/* Note that data contains PPMIS=1 and =2 records,   */
/* since they are needed for computing Eligibility   */
/* Criteria, but the PPMIS=2 records are deleted as  */
/* soon as possible after that point.                */

data famguys;
 set family.fam87;
 length afdcsize 3;
/* single parent & kids */
 if famstr in(1,3) then afdcsize=numkids+ochrefgd+1; 
/* two parents & kids */
 if famstr eq 2 then afdcsize=numkids+ochrefgd+2;    
 if afdcsize gt 9 and afdcsize ne . then afdcsize=9;
 keep sunique age mnum date state afdcsize ppid hhaddi famid relat
       ubrthmn ubrthyr ppmis;
run;


/* ************************************************************* */
/* ************** merge in the min_une data ******************** */
/* ************************************************************* */
data addvars;
 set famguys;
 length year month 3;
 year=int(date/100);
 month=date-(year*100);
run;
proc datasets; delete famguys;
proc sort data=addvars; by state year month;
proc sort data=sipp.min_une3 out=min_une3; by state year month;
data addvars;
 merge addvars(in=infam) min_une3(in=inmin); by state year month;
 if       infam=1 and inmin=1 then merged=1; /*indiv. in id'd states*/
  else if infam=1 and inmin=0 then merged=2; /*indiv in non-id'd states*/
  else if infam=0 and inmin=1 then merged=3; /*data for non-id'd states*/
  else if infam=0 and inmin=0 then merged=4; /*should not exist*/
  else                             merged=5; /*should not exist*/
run;
proc datasets; delete min_une3;
run;
title 'Min_unemp merge';
proc freq; tables merged;
run;
data addvars;
 set addvars;
 if merged in(1,2);
 drop merged;
run;

/* ************************************************************* */
/* *************** merge in the ben10 data ********************* */
/* ************************************************************* */
proc sort data=addvars; by year state afdcsize;
proc sort data=sipp.ben10 out=ben10; by year state afdcsize;
data addvars;
 merge addvars(in=infam) ben10(in=inben); by year state afdcsize;
 if       infam=1 and inben=1 then merged=1; /*indiv. in id'd states*/
  else if infam=1 and inben=0 then merged=2; /*indiv in non-id'd states*/
  else if infam=0 and inben=1 then merged=3; /*data for non-id'd states/yrs*/
  else if infam=0 and inben=0 then merged=4; /*should not exist*/
  else                             merged=5; /*should not exist*/
run;
proc datasets; delete ben10;
run;
title 'Ben10 merge';
proc freq; tables merged;
run;
data addvars;
 set addvars;
 if merged in(1,2);
 mpov=povline/12;
 drop merged povline sname;
run;

***********************************************************;
***Section 6***********************************************;
***section to get eligibility criteria for children attached;
***********************************************************;

/* work with the kids to get the data in the shape needed */
data kids;
 set addvars
  (keep= sunique mnum ubrthyr ubrthmn date age cpstate hhaddi famid ppid
          relat minwage mpov);
/* Only keep children of reference person and other relative of */
/* reference person lt 19 and with reference person as guardian.*/
 if (relat eq 3 and age lt 19) or relat eq 14; 

/* make child's birthdate */
 brthyr=ubrthyr-1900;
 birthday=(brthyr*100)+ubrthmn;

/* Lara's code to compute POVKID,POVINF by state & date:*/
/* At bottom, creates AGEEL,MEDLEV,EL40M,EL30M per kid. */

%INCLUDE 'eligibility_criteria_for_children.sas';

/* Keep only the variables required for the final dataset */
keep  mnum age hhaddi famid ppid ageel medlev el40m el30m;
run;

/* Take Lara's AGEEL,MEDLEV,EL40M,EL30M per kid     */
/* and sum them by family to create                 */
/* AGEELIG,YOUNGLIM,OLDLIM,EL40MIN,EL30MIN          */
/* (i.e., kid's min/max/mean values, by family).    */
proc sort; by mnum ppid hhaddi famid;
proc summary data=kids;
 by mnum ppid hhaddi famid;
 var ageel medlev el40m el30m;
 output out=kiddat
   mean(ageel)=ageelig
   max(medlev)=younglim
   min(medlev)=oldlim
   mean(el40m)=el40min
   mean(el30m)=el30min;
run;
/* Add the Eligibility Criteria for Children to main dataset */
proc sort data=addvars; by mnum ppid hhaddi famid;
data addvars;
 length younglim oldlim 3;
 merge addvars kiddat;
 by mnum ppid hhaddi famid;
/* Determine whether mother's youngest child could qualify  */
/* for Medicaid if she worked 30 or 40 hours at the minimum */
 yelig40=(((minwage*160)/mpov)*100) < younglim;
 yelig30=(((minwage*120)/mpov)*100) < younglim;
/* Compute an additional variable */
 ylimamt=(younglim/100)*mpov;
/* Finished with PPMIS=2 records - drop them now */
 if ppmis eq 1;
 drop _type_ _freq_ ppmis; /* PPMIS always =1 so not needed in dataset */
run;
title 'After Eligibility Criteria for Children merge';
proc contents;
run;
options nolabel;
proc means;
run;
options label;
proc datasets;
  delete kiddat kids;


/* ************************************************************* */
/* ******* merge in the Child and Adult Disability data ******** */
/* ************************************************************* */
/* Recode Disability info as requested by Lara in January 2004   */
/*                                                               */

/* Merge in Child Disability from TopicalModule6 */
proc sort data=addvars; by sunique;
data addvars;
 merge addvars(in=infam) family.kdisab87(keep=sunique kdisab); by sunique;
 if infam;
run;

/* Add variable DISKID - number of disabled kids in family  */
/* Note: DISKID=. if ANY kids in the family have KDISAB=.   */
/* because that means we don't know the answer to the       */
/* question about how many kids in the family are disabled. */
/* DISKID=0 implies there was at least one kid in the family*/
/* and that kid could have been identified as disabled, but */
/* there were no kids who WERE identified as disabled.      */
data kids;
 set addvars;
 if (relat eq 3 and age le 18) or relat eq 14; /* only keep kids */
 keep mnum ppid hhaddi famid kdisab;
run;
proc sort data=kids; by mnum ppid hhaddi famid;
proc summary data=kids;
 by mnum ppid hhaddi famid;
 var kdisab;
 output out=diskd 
   sum(kdisab)=diskid     /* get sum of disabled kids in family */
   nmiss(kdisab)=dismiss; /* get number of missing values of KDISAB */
run;
proc sort data=addvars; by mnum ppid hhaddi famid;
data addvars;
 merge addvars diskd; by mnum ppid hhaddi famid;
 length diskid 3;
/* Reset to missing if ANY kids in family have KDISAB=. */
 if dismiss gt 0 then diskid=.;  
 drop _freq_ _type_ dismiss;
run;
proc datasets; delete kids diskd;
title 'Number of Disabled Children in family';
proc freq; tables diskid;
run;

/* Get Adult Disability from TopicalModule6 */
data adis;
 set disab.adisab87(keep=sunique adisab sevlim);
proc sort; by sunique;
run;
/* Make list of people in Family file who were around for TM6 */
data tm6guys;
 set addvars;
/* Keep only those in data for wave6 */
 if mnum in(21,22,23,24,25);
 keep sunique;
proc sort nodupkey; by sunique;
run;
data adis;
 merge adis(in=ad) tm6guys(in=tm6); by sunique;
 if ad and tm6;
run;
/* Get Adult Work Limitation from TopicalModule7 */
data adis2;
 set disab.awklim87(keep=sunique worklim);
proc sort; by sunique;
/* Make list of people in Family file who were around for TM7 */
data tm7guys;
 set addvars;
/* Keep only those in data for wave7 */
 if mnum in(25,26,27,28);
 keep sunique;
proc sort nodupkey; by sunique;
run;
data adis2;
 merge adis2(in=awkl) tm7guys(in=tm7); by sunique;
 if awkl and tm7;
run;
/* Join both adult disability datasets: general & work limitation */
data adis;
 merge adis adis2; by sunique;
/* Set SEVLIM=1 if WORKLIM=1 as per Lara Shore-Sheppard Nov. 23, 2004 */
 if worklim eq 1 then sevlim=1;
run;
/* Print a table showing comparison of the two adult datasets */
title 'AdultDisability from TM6 vs WorkLimitation from TM7';
proc freq; tables adisab*worklim /missing norow nocol nopercent;
run;
proc sort data=addvars; by sunique;
data addvars;
 merge addvars(in=infam) adis(in=indis); by sunique;
 if infam;
/* Find minimum age of each person, to use for identifying adults */
 retain minage;
 if first.sunique then minage=age;
proc datasets; delete adis adis2 tm6guys tm7guys;
run;

data chk;
 set addvars;
 if adisab eq 1 and age le 18;
title 'Adult Disability from TM6 for people less than 19 years old';
proc freq; tables adisab*age /missing norow nocol nopercent;
run;

/* Create DISAB based on ADISAB WORKLIM and KDISAB  */
/*                                                  */
data addvars;
 length kdisab adisab sevlim disab 3;
 set addvars;
 disab=.;
/* Use all KDISAB values */
 if kdisab ne . then disab=kdisab;
/* If person is an adult */
 if minage ge 15 then
   do;
/* Use ADISAB =1 */
   if adisab eq 1 then disab=1;
/* Use ADISAB =0 only if DISAB not already =1 from KDISAB */
   if adisab eq 0 and disab ne 1 then disab=0;
/* Use WORKLIM =1 */
   if worklim eq 1 then disab=1;
/* Since WORKLIM is a more narrow question than ADISAB, leave */
/* DISAB unchanged if WORKLIM =0 or =.                        */
   end;
 drop minage worklim;
run;

/* Merge in Immigration data from TopicalModule2 */
data immig;
 length immig noncit 3;
 set immig.immig87;
 keep sunique immig noncit;
proc sort; by sunique;
run;
data addvars;
 merge addvars (in=infam) immig(in=inimm); by sunique;
 if       infam=1 and inimm=1 then merged=1; /*cases in both data*/
  else if infam=1 and inimm=0 then merged=2; /*not interv in imm. wave*/
  else if infam=0 and inimm=1 then merged=3; /*ppmis not 1 in core data*/
  else if infam=0 and inimm=0 then merged=4; /*should be none of these*/
  else                             merged=5; /*should be none of these*/
run;
proc datasets; delete immig;
run;
title 'Immigrant Merge';
proc freq; tables merged;
run;

/* Set variable labels for Disability and Immigration variables */
data addvars;
 set addvars;
 if merged in(1,2);
 drop merged;
 label adisab= '=1 if adult disability'
       sevlim= '=1 if adult disability is severe'
       kdisab= '=1 if child disability'
       disab=  '=1 if disability (adult or child)'
       immig=  '=1 if person born outside US'
       noncit= '=1 if person not a US citizen';
run;
title 'Disability and immigrant vars post-merge';
proc means; var disab adisab sevlim kdisab immig noncit;
run;
proc freq; tables adisab*kdisab*sevlim /missing norow nocol nopercent;
run;

/* ************************************************************* */
/* *********** merge in the "fixed" HIGRAD data **************** */
/* ************************************************************* */
proc sort data=addvars; by sunique date;
data higrad;
 set higrad.schl87(keep=sunique date hgrad inschl);
 rename inschl=enroll;
proc sort; by sunique date;
run;
title 'Means of higrad data';
proc means;
run;
data addvars;
merge addvars(in=infam) higrad(in=inhi); by sunique date;
 if       infam=1 and inhi=1 then merged=1; /*cases with fixes, or not--want*/
  else if infam=1 and inhi=0 then merged=2; /*should not exist*/
  else if infam=0 and inhi=1 then merged=3; /*may be month not in sample cases*/
  else if infam=0 and inhi=0 then merged=4; /*should not exist*/
  else                            merged=5; /*should not exist*/
run;
proc datasets; delete higrad;
run;
title 'Higrad merge';
proc freq; tables merged;
run;
data addvars;
 set addvars;
 if merged eq 1;
 drop merged;
run;


/* ************************************************************* */
/* *************** merge in the fmapv6 data ******************** */
/* ************************************************************* */
proc sort data=sipp.fmapv6 out=fmapv6; by state year;
proc sort data=addvars; by state year;
data addvars;
 merge addvars(in=infam) fmapv6(in=infmp); by state year;
 if       infam=1 and infmp=1 then merged=1; /*obs I want*/
  else if infam=1 and infmp=0 then merged=2; /*states not id'd*/
  else if infam=0 and infmp=1 then merged=3; /*states not in SIPP87*/
  else if infam=0 and infmp=0 then merged=4; /*should not exist*/
  else                             merged=5; /*should not exist*/
run;
proc datasets; delete fmapv6;
run;
title 'FMAP merge';
proc freq; tables merged;
           tables merged*state /norow nocol nopercent;
           tables merged*year /norow nocol nopercent;
run;
data addvars;
 set addvars;
 if merged in(1,2);
 drop merged abbrev erate year4;
run;

/* ************************************************************* */
/* *************** merge in the mkreal data ******************** */
/* ************************************************************* */
proc sort data=addvars; by date;
proc sort data=sipp.mkreal out=mkreal; by date;
data addvars;
 merge addvars(in=infam) mkreal(in=inreal); by date;
 if       infam=1 and inreal=1 then merged=1; /*obs I want*/
  else if infam=1 and inreal=0 then merged=2; /*too early, too late*/
  else if infam=0 and inreal=1 then merged=3; /*dates not in SIPP87*/
  else if infam=0 and inreal=0 then merged=4; /*should not exist*/
  else                              merged=5; /*should not exist*/
run;
proc datasets; delete mkreal;
run;
title 'Mkreal merge';
proc freq; tables merged;
           tables merged*date /norow nocol nopercent;
run;
proc sort data=addvars; by sunique mnum;
run;
data addvars;
 set addvars;
 if merged in(1,2);
 drop merged;
run;


title 'Means of basic data after several merges';
options nolabel;
proc means;
run;
options label;
proc contents;


/* Merge the additional variables with the SIPP data */

data all87;
 merge family.fam87 more87; by sunique mnum;
 if ppmis ne 1 then delete;
 drop ppmis;
run;

data family.all87;
 merge all87 addvars; by sunique mnum;

/* Add other necessary variables */
 length intmon femhead twopar othhead 3 abbrev $ 2;

 intmon=mod(mnum,4); /* Interview month within wave */
 if intmon eq 0 then intmon=4;

 femhead=(famstr=1);
 twopar=(famstr=2);
 othhead=(famstr in(3,4,5,6) );

 if state not in(61,62,63,0) then abbrev=fipstate(state);
 
/* Compute additional AFDC variables */
 gross=1.85*mneed;
 if date>8409 and date<8910 then do;
	md618=160*(kidlt18-kidlt6);
	md06=160*kidlt6;
	md612=160*(kidlt12-kidlt6);
	md1218=160*(kidlt18-kidlt12);

	md06_1=md06;
	md618_1=md618;
	md612_1=md612;
	md1218_1=md1218;

	yw=mpay+105;
	yw_1=1.5*mpay+105;
 end;
 else if date ge 8910 and date<9610 then do;
	md618=175*(kidlt18-kidlt6);
	md06=175*kidlt6+25*kidlt2;
	md612=175*(kidlt12-kidlt6);
	md1218=175*(kidlt18-kidlt12);

	md06_1=1.5*md06;
	md618_1=1.5*md618;
	md612_1=1.5*md612;
	md1218_1=1.5*md1218;

	yw=mpay+120;
	yw_1=1.5*mpay+120;
 end;
 afdclev1=min(gross, yw_1 + md06_1);
 afdclev2=min(gross, yw + md06);

/* Comment: Note the following when using the AFDC variables:   */
/* To run regressions with the afdc variables entered           */
/* separately, need to include                                  */
/*	(yw OR yw_1)	and                                     */
/*	daycare vars	--either                                */
/*	  (md06 and md618)--after 1st 4 mos. OR                 */
/*	  (md06_1 and md618_1)--1st 4 mos. OR                   */
/*	  (md06 and md612 and md1218)--after 1st 4 mos. OR      */
/*	  (md06_1 and md612_1 and md1218_1)--1st 4 mos.         */

/* Labels for the AFDC variables                                */
label 	gross= 'Gross test, nominal $'
	md618= 'Max daycare kids 6-17'
	md06= 'Max daycare kids < 6'
	md612= 'Max daycare kids 6-11'
	md1218= 'Max daycare kids 12-17'
	md06_1= 'Max daycare kids <6 1st 4 mos.'
	md618_1= 'Max daycare kids 6-17 1st 4 mos'
	md612_1= 'Max daycare kids 6-11 1st 4 mos'
	md1218_1= 'Max daycare kids 12-17 1st 4 mos'
	yw= 'Pay std plus disregard'
	yw_1= 'Pay std plus disregard 1st 4 mos'
	afdclev1= 'Max inc 1st 4 mos assum. dc kids <6 only'
	afdclev2= 'Max inc all mos assum. dc kids <6 only'
;

/* Include SAS code for Welfare Waiver variables and their labels */

%INCLUDE 'welfare_waivers.sas';


/* Labels for all the other variables                          */
label	
	abbrev   = 'Two-character state abbreviation'
	afdc     = '=1 if on AFDC'
	afdcimp  = 'Monthly AFDC receipt imputed'
	afdcrec  = 'Received AFDC income this month'
	afdcsize = 'Fam size for AFDC determination'
	age      = 'Age in years'
	ageelig  = 'Fraction of kids w/expansion eligibility'
	allwel   = 'Total welfare income for indiv'
	anyafdc  = 'Number of fam members on AFDC'
	black    = 'Individual is black'
	busid1   = 'Id of first self-employment'
	busid2   = 'Id of second self-employment'
	champ    = '=1 if on CHAMPUS'
	chpres   = 'Children in family related to RefPerson'
	dadpres  = 'Dad present in family this month'
	date     = 'Date in YYMM format'
	diskid   = 'Number of disabled kids in family'
	el30min  = 'Frac kids elig if mom works 30hrs at min'
	el40min  = 'Frac kids elig if mom works 40hrs at min'
	empgr    = 'Employment growth rate in state'
	empl     = '=1 if employed'
	enroll   = '=1 if enrolled in school, Eileen fixed'
	esr      = 'Employment status recode'
	ethncty  = 'Ethnic origin--not mut excl w/race'
	famafdc  = 'Family income from AFDC'
	famid    = 'Family id (w/mnum,ppid, hhaddi)'
	faminc   = 'Family income'
	famnum   = 'Number of subfamily'
	famrel   = 'Relationship in subfamily'
	famstr   = 'Family structure code, smom=1,twopar=2'
	famtyp   = 'Primary or subfamily or individual'
	famwelf  = 'Family welfare income'
	famwsal  = 'Family wage and salary income'
	femhead  = 'Female headed-family'
	fnlwt87  = 'Weight for 1987 year'
	fnlwt88  = 'Weight for 1988 year'
	fnlwt89  = 'Weight for 1989 year'
	fnlwt90  = 'Weight for 1990 year'
	fnlwt91  = 'Weight for 1991 year'
	fnlwt92  = 'Weight for 1992 year'
	fnlwt93  = 'Weight for 1993 year'
	fnlwt94  = 'Weight for 1994 year'
	foodst   = 'Recv food stamps 1=yes'
	gaimp    = 'Monthly GA receipt imputed'
	garec    = 'Received GA income this month'
	gasst    = 'Recv general asst 1=yes'
	genasst  = 'Amount of GA rec this month'
	hgrad    = 'Highest grade completed, Eileen fixed'
	hhaddi   = 'Current household address id'
	hiemp    = '=1 if HI through employer'
	hioth    = '=1 if HI in others name'
	hiown    = '=1 if HI in own name'
	hispanic = 'Individual has Hispanic ethnicity'
	intmon   = 'Interview month within wave, =1-4'
	jobid1   = 'Id of first job'
	jobid2   = 'Id of second job'
	kidlt12  = 'Number of kids lt 12 in family'
	kidlt18  = 'Number of kids lt 18 in family'
	kidlt2   = 'Number of kids lt 2 in family'
	kidlt6   = 'Number of kids lt 6 in family'
	mcaid    = '=1 if on Medicaid'
	mcare    = '=1 if on Medicare'
	minwage  = 'Current minimum wage'
	mkreal   = 'Multiplier to obtain real values'
	mneed    = 'State AFDC monthly need standard'
	mnotafdc = 'Recv Medicaid and not AFDC'
	mnum     = 'Month number'
	mompres  = 'Mom present in family this month'
	mpay     = 'State AFDC monthly payment standard'
	mpov     = 'Monthly poverty line, nominal $'
	ms       = 'married=1 2,wid=3,div=4,sep=5,nev mar=6'
	nilf     = '=1 if not in labor force'
	nmtot    = 'Number of months with PPMIS=1'
	npersns  = 'number of people in family this month'
	numkids  = 'Number of kids in family'
	nummths  = 'Number of months woman was smom'
	ochrefgd = '"Other" children w/RefPerson as Guardian'
	oldest   = 'Age of oldest child'
	oldlim   = 'Medicaid income limit for oldest child'
	othchldn = 'Other children in family (relat=4&5)'
	othhead  = 'Family has other head'
	othwelf  = 'Amount of oth welf rec this month'
	othwimp  = 'Monthly oth welf receipt imputed'
	othwrec  = 'Received oth welf. inc. this month'
	parguard = '=1 if PARID comes from Guardian info'
	persafdc = 'Amount of AFDC rec this month'
	pnlwgt   = 'Weight in panel'
	ppearn   = 'Person monthly earnings'
	ppentry  = 'Entry address id: part of unique id'
	ppid     = 'ID of hh: part of unique id'
	ppinc    = 'Person monthly income'
	pppnum   = 'Person no. w/in hh: part of unique id'
	priv     = 'Has private health ins'
	race     = 'white=1,black=2,native am.=3,asian=4'
	rate     = 'Fed Medicaid Assistance Pct to state'
	relat    = 'Family relat.,head=1,sp=2,kid=3,oth=4'
	rot      = 'Rotation group: 1-4'
	rrp      = 'Relationship to reference person'
	sex      = '1=male; 2=female'
	smom     = 'Single mom in this month'
	ssiamt   = 'Amount of SSI rec this month'
	ssiimp   = 'Monthly SSI receipt imputed'
	ssirec   = 'Received SSI income this month'
	twopar   = 'Two-parent family'
	ubrthmn  = 'Month of birth'
	ubrthyr  = 'Year of birth'
	wdisab   = 'DISAB from main SIPP data'
	yelig30  = 'Youngest elig if worked 30 hrs at min'
	yelig40  = 'Youngest elig if worked 40 hrs at min'
	ylimamt  = 'Nominal income limit for youngest'
	youngest = 'Age of youngest child'
	younglim = 'Medicaid income limit for youngest child'
;

run;

title 'Means of data for all people in the SIPP';
options nolabel;
proc means;
run;

title 'Means of women who are ever a SingleMother';
data tmp;
 set family.all87;
/* Get record if was SingleMother at least one month */
 if nummths gt 0; 
/* Get rid of moms in non-singularly identified states */
 if state in (61,62,63,0) then delete; 
run;
proc means;
run;

proc freq;
tables smom*relat;
run;

title 'Means of women who are a SingleMother in current month';
data tmp;
 set family.all87;
/* Get record if was SingleMother this month */
 if smom eq 1;
/* Get rid of moms in non-singularly identified states */
 if state in (61,62,63,0) then delete;
run;
proc means;
run;

proc freq;
tables smom*relat;
run;



***********************************************************;
*Note that all variables are NOT in real terms.  In order
*to do that, just multiply the variable in question by the 
*variable mkreal.  Note that mkreal is missing for 1985
*values, and only goes through 9612.
***********************************************************;

***********************************************************;
*Still need to attach the waiver data--for AFDC and for 
*Medicaid.  Also need to attach the SCHIP data if we want
*to be as complete as possible.
***********************************************************;


