options linesize=80 nocenter pagesize=66;

/* Modified version of program, to deal with anomolies in the   */
/* 1988 SIPP Topical Module questions.  This version of the     */
/* program drops all "Does ... have any difficulty ..." and     */
/* "Does...need help" questions for people who did not indicate */
/* that they have at least one non-temporary health condition,  */
/* and it keeps all the "Is ... able to" questions, regardless  */
/* of whether or not they have at least one non-temporary health*/
/* condition.  These changes help make 1988 more consistent with*/
/* the other SIPP years.                                        */

*adisab886.sas: Adult disability information for 1988 from topical module
 wave 6;
*Date: 07/14/03;

libname disab '';
/* filename in1 PIPE 'gunzip -c ~ldshore/disk2/sipp/1988/da9568.recwave6.gz'; */
filename in1 'c:\SIPP_data\sipp88rt6.dat';

*Adult disability;
Data adults;
infile in1 lrecl=6200 missover;

input
@6	PPID		9.
@15	ROT		1.
@2049   PPMIS           1.
@2050	PPENTRY		2.
@2052	PPPNUM		3. 
@5951	TM8500		1.
@5952   tm8502          1.
@5953	TM8504		1.
@5966	TM8522		1.
@5979	TM8540		1.
@5995	TM8562		1.
@6008	TM8580		1.
@6027	TM8602		1.
@6162	TM8900		1.
@6163	TM8902		1.
@6165	TM8906		1.
@6166	TM8908		1.
@6167	TM8910		1.
@6168	TM8912		1.
@6169	TM8914		1.
@6170	TM8916		1.
@6171	TM8918		1.	
@6172	TM8920		1.
@6173	TM8922		1.
@6174	TM8924		1.
@6175	TM8926		1.
@6176	TM8928		1.
@6177	TM8930		1.
@6178	TM8932		1.
@6179	TM8934		1.
@6180	TM8936  	1.;

/* Recode the variables corresponding to the     */
/* questions in 1990 and later which only apply  */
/* to temporary conditions, so that they are NOT */
/* counted as denoting a disability (these are   */
/* the "Does ... have any difficulty ..." and the*/
/* "Does...need help" questions), but retain the */
/* "Is ... able to" questions, regardless of     */
/* whether or not the person has at least one    */
/* non-temporary health condition.               */
 if tm8502 ne 1 then
  do;
    tm8900=0;
    tm8906=0;
    tm8910=0;
    tm8912=0;
    tm8914=0;
    tm8918=0;
    tm8922=0;
    tm8926=0;
    tm8928=0;
    tm8930=0;
    tm8932=0;
    tm8934=0;
    tm8936=0;
  end;

if (TM8500=1 or TM8900=1 or TM8906=1
 or TM8910=1 or TM8912=1 or TM8914=1
 or TM8918=1 or TM8922=1 or TM8926=1
 or TM8930=1 or TM8934=1) then funclim=1;
else funclim=0;

if (TM8500=1 or TM8504=1 or TM8522=1
 or TM8540=1 or TM8562=1 or TM8562=2
 or TM8580=1 or TM8602=1 or TM8902=2
 or TM8908=2 or TM8916=2 or TM8920=2
 or TM8924=2 or TM8928=1 or TM8932=1
 or TM8936=1) then sevlim=1;
else sevlim=0;

if (sevlim=0) and (funclim=1) then modlim=1;
else modlim=0;

*recode TM8562 no=3 to be no=0 and yes=2 to be yes=1 so can sum variables to
 obtain number of limitations;
if TM8562=2 then TM8562=1;
else if TM8562=3 then TM8562=0;

*recode no=2 to be no=0 so can sum variables to obtain number of limitations;
array disvars{15} TM8504 TM8522 TM8540 TM8580 TM8602 TM8900 TM8906 TM8910
 TM8912 TM8914 TM8918 TM8922 TM8926 TM8930 TM8934;
do i=1 to 15;
    if disvars{i}>1 then disvars{i}=0;
end;
drop i;

sumvar= (TM8504 + TM8522 + TM8540 + TM8562 + TM8580 + TM8602 + TM8900
 + TM8906 + TM8910 + TM8912 + TM8914 + TM8918 + TM8922 + TM8926
 + TM8930 + TM8934);

if (sumvar>1) then plus2lim=1;
else plus2lim=0;

if (plus2lim=0) and (funclim=1) then onelim=1;
else onelim=0;

if (TM8504=1 or TM8900=1 or TM8906=1 or TM8910=1 or TM8930=1 or TM8934=1)
 then adllim=1;
else adllim=0;

if (adllim=0) and (funclim=1)
 then iadllim=1;
else iadllim=0;

*define the broadest definition of disability, following Powers
 and McNeil;
if (funclim=1 or sevlim=1 or modlim=1 or plus2lim=1 or onelim=1 or
 adllim=1 or iadllim=1) then adisab=1;
else adisab=0;

syear='88';
id1='000000000';
id1=PPID;
id2='00';
id2=PPENTRY;
id3='000';
id3=PPPNUM;
sunique=syear||id1||id2||id3;
run;

proc means;

proc freq;
tables adllim*iadllim;

data disab.adisab88;
set adults;
if (ppmis = 1);
keep PPID ROT PPENTRY PPPNUM funclim sevlim modlim
 plus2lim onelim adllim iadllim adisab sunique;
run;

proc means; var adisab;
run;

