options linesize=80 nocenter pagesize=66;
*adisab965.sas: Adult disability information for 1996 from topical module
 wave 5;
*Date: 06/01/06;

/* All variables related to disability are read in, but they are      */
/* not all used in our definition of adult disability.  The unused    */
/* variables include those that indicate a specific medical condition,*/
/* mental disabilities, and any ADL/IDAL/FunctionalLimitations that   */
/* are new in 1996 and/or were not used in previous years.            */

libname disab '';

filename in1 'c:\SIPP_data\sipp96t5.dat';

*Adult disability;
data adults;
 infile in1 lrecl=2044  missover;
 input
  @6    PPID    12. /* SSUID     */
  @24   ROT      1. /* SROTATION */
  @48   PPPNUM   4. /* EPPNUM    */
/* Ignore "interview" variables - PPMIS4 =1 in all TM records */
/*  @53  PPINTVW   2.  1,2=interview; 3,4=non-interview; 5=child < 15 */
/*  @55  PPMIS4    1.  1=interview; 2=non-interview */
  @72   AGE      2. /* EAGE     */
  @1450 EPADUNV  2. /* Universe indicator: All adults     */
/*                     1=in-universe; -1=not-in-universe */

/* For the following, responses are: */
/*      -1 .Not in universe          */
/*       1 .Yes                      */
/*       2 .No                       */
/*  (additional values listed below  */
/*   each item, if they exist)       */
  @1455 ECANE    2. /* ADQ: Use of a cane, crutches, or walker  */
/*     ADQ2@1 Does the person use a cane, crutches, or walker? */
  @1458 EWCHAIR  2. /* ADQ: Use of wheelchair or an electric scooter   */
/*     ADQ2@2 Does the person use a wheelchair or an electric scooter? */
  @1461 EHEARAID 2. /* ADQ: Use of a hearing aid */
/*     ADQ2@3 Does the person use a hearing aid? */
  @1464 ECANE6   2. /* ADQ: Use of an aid for six months or longer */
/*     ADQ3 Has the person used a cane, crutches, or a walker for  */
/*     six months or longer?                                       */
  @1467 ESEEDIF  2. /* ADQ: Difficulty seeing words in newspaper print  */
/*     ADQ4 Does the person have difficulty seeing the words and letters*/
/*     in ordinary newspaper print - even when wearing glasses or       */
/*     contact lenses if the person usually wears them?                 */
/*     V          3 .Person is blind                                    */
  @1470 ESEENOT  2. /* ADQ: Ability to see words in print at all */
/*     ADQ5 Is the person able to see the words and letters in   */
/*     ordinary newspaper print at all?                          */
  @1473 EHEARDIF 2. /*ADQ: Difficulty hearing a normal conversation */
/*     ADQ6 Does the person have difficulty hearing what is said in */
/*     a normal conversation with another person even when wearing  */
/*     his/her hearing aid?                                         */
/*     V          3 .Person is deaf                                 */
  @1476 EHEARNOT 2. /* ADQ: Ability to hear what is said at all */
/*     ADQ7 Is the person able to hear what is said in a normal */
/*     conversation at all? */
  @1479 ESPEECHD 2. /* ADQ: Difficulty having speech understood */
/*     ADQ8 Does the person have any difficulty having his/her  */
/*     speech understood?                                       */
  @1482 ESPEECHC 2. /* ADQ: Ability to understand speech at all */
/*     ADQ9 In general, are people able to understand the       */
/*     person's speech at all?                                  */
  @1485 EDIF10   2. /* ADQ: Difficulty lifting and carrying 10 pounds */
/*     ADQ10 Does the person have any difficulty lifting and carrying */
/*     something as heavy as 10 pounds - such as a full bag of        */
/*     groceries?                                                     */
  @1488 ECANT10  2. /* ADQ: Ability to lift and carry 10 pounds at all     */
/*     ADQ11 Is the person able to lift and carry this much weight at all? */ 
  @1491 EDIF25   2. /* ADQ: Difficulty lifting and carrying 25 pounds */
/*     ADQ12 Would the person have any difficulty lifting and carrying*/
/*     something heavier - say a 25 pound bag of pet food?            */
  @1494 ECANT25  2. /* ADQ: Ability to lift and carry 25 pounds at all */
/*     ADQ13 Would the person be able to lift and carry a 25 pound bag */
/*     of pet food at all?                                             */
  @1497 EPUSHD   2. /* ADQ: Difficulty pushing or pulling large objects */
/*     ADQ14 Does the person have any difficulty pushing or pulling     */
/*     large objects such as a living room chair?                       */
  @1500 EPUSHC   2. /* ADQ: Ability to push or pull large objects at all  */
/*     ADQ15 Is the person able to push or pull such large objects at all?*/
  @1503 ESTANDD  2. /* ADQ: Difficulty standing or being on feet */
/*     ADQ16@1 Does the person have any difficulty standing or   */
/*     being on his/her feet for one hour?                       */
  @1506 ESITD    2. /* ADQ: Difficulty sitting     */
/*     ADQ16@2 Does the person have any difficulty */
/*     sitting for one hour?                       */
  @1509 ESTOOPD  2. /* ADQ: Difficulty stooping, crouching, or kneeling */
/*     ADQ16@3 Does the person have any difficulty stooping, crouching, */
/*      or kneeling?                                                    */
  @1512 EREACHD  2. /* ADQ: Difficulty reaching over head   */
/*     ADQ16@4 Does the person have any difficulty reaching */
/*     over his/her head?                                   */
  @1515 EGRASPD  2. /* ADQ: Difficulty using hands and fingers  */
/*     ADQ17 Does the person have any difficulty using his/her  */
/*     hands and fingers to do things such as picking up a glass*/
/*     or grasping a pencil?                                    */
  @1518 EGRASPC  2. /* ADQ: Ability to use hands and fingers at all */
/*     ADQ18 Is the person able to use his/her hands and fingers to */
/*     grasp and handle at all?                                     */
  @1521 ESTAIRSD 2. /* ADQ: Difficulty walking up a flight of stairs *
/*     ADQ19 Does the person have any difficulty walking up a flight */
/*     of 10 stairs?                                                 */
  @1524 ESTAIRSC 2. /* ADQ: Ability to walk up a flight of stairs at all */
/*     ADQ20 Is the person able to walk up a flight of 10 stairs at all? */
  @1527 EWALKD   2. /* ADQ: Difficulty walking a quarter of a mile */
/*     ADQ21 Does the person have any difficulty walking a quarter */
/*     of a mile - about three city blocks?                        */
  @1530 EWALKC   2. /* ADQ: Ability to walk a quarter of a mile at all */
/*     ADQ22 Is the person able to walk a quarter of a mile at all?    */
  @1533 ETELED   2. /* ADQ: Difficulty using an ordinary telephone */
/*     ADQ23 Does the person have any difficulty using an ordinary */
/*     telephone?                                                  */
  @1536 ETELEC   2. /* ADQ: Ability to use a telephone at all        */
/*     ADQ24 Is the person able to use an ordinary telephone at all? */

/* Instructions to the SIPP interviewer for the following */  
/* twelve ADL and IADL "difficulty" questions says:       */
/* FR NOTE: EXCLUDE THE EFFECTS OF TEMPORARY CONDITIONS - IF AN AID   */
/* IS USED, ASK WHETHER THE PERSON HAS DIFFICULTY WHEN USING THE AID. */
  @1539 EINDIF   2. /* ADQ: Difficulty getting around inside the home */
/*     ADQ25@1 Because of a physical or mental health condition, does */
/*     the person have difficulty getting around inside the home?     */
  @1542 EOUTDIF  2. /* ADQ: Difficulty going outside the home   */
/*     ADQ25@2 Because of a physical or mental health condition,*/
/*     does the person have difficulty going outside the home,  */
/*     for example, to shop or visit a doctor's office?         */
  @1545 EBEDDIF  2. /* ADQ: Difficulty getting in and out of bed or chair */
/*     ADQ25@3 Because of a physical or mental health condition, does the */
/*     person have difficulty getting in and out of bed or a chair?       */
  @1548 EBATHDIF 2. /* ADQ: Difficulty taking a bath or shower  */
/*     ADQ25@4 Because of a physical or mental health condition,*/
/*     does the person have difficulty taking a bath or shower? */
  @1551 EDRESSD  2. /* ADQ: Difficulty dressing             */
/*     ADQ25@5 Because of a physical or mental health       */
/*     condition, does the person have difficulty dressing? */
  @1554 EWALK2D  2. /* ADQ: Difficulty walking                  */
/*     ADQ25@6 Because of a physical or mental health condition,*/
/*     does the person have difficulty walking?                 */
  @1557 EEATDIF  2. /* ADQ: Difficulty eating             */
/*     ADQ25@7 Because of a physical or mental health     */
/*     condition, does the person have difficulty eating? */
  @1560 ETOILETD 2. /* ADQ: Difficulty using or getting to the toilet */
/*     ADQ25@8 Because of a physical or mental health condition, does */
/*     the person have difficulty using or getting to the toilet?     */
  @1563 EMONEYD  2. /* ADQ: Difficulty keeping track of money and bills */
/*     ADQ25@9 Because of a physical or mental health condition, does   */
/*     the person have difficulty keeping track of money and bills?     */
  @1566 EMEALSD  2. /* ADQ: Difficulty preparing meals           */
/*     ADQ25@10 Because of a physical or mental health condition,*/
/*     does the person have difficulty preparing meals?          */
  @1569 EHWORKD  2. /* ADQ: Difficulty doing light housework      */
/*     ADQ25@11 Because of a physical or mental health condition, */
/*     does the person have difficulty doing light housework such */
/*     as washing dishes or sweeping a floor?                     */
  @1572 EMEDD    2. /* ADQ: Difficulty taking right amount of medicine */
/*     ADQ25@12 Because of a physical or mental health condition, does */
/*     the person have difficulty taking the right amount of           */
/*     prescribed medicine at the right time?                          */

/* For each of the 12 ADL/IADL questions, if the person indicated */
/* they have difficulty, these questions ask if they need help.   */
  @1575 EINHELP  2. /* ADQ: Need help getting around inside the home */
/*     ADQ26@1 Does the person need the help of another person with  */
/*     getting around inside the home?                               */
  @1578 EOUTHELP 2. /* ADQ: Need help going outside the home   */
/*     ADQ26@2 Does the person need the help of another person */
/*     with going outside the home, for example, to shop or    */
/*     visit a doctor's office?                                */
  @1581 EBEDHELP 2. /* ADQ: Need help getting in and out of bed or a chair */
/*     ADQ26@3 Does the person need the help of another person with        */
/*     getting in and out of bed or a chair?                               */
  @1584 EBATHH   2. /* ADQ: Need help taking a bath or shower  */
/*     ADQ26@4 Does the person need the help of another person */
/*     with taking a bath or shower?                           */
  @1587 EDRESSH  2. /* ADQ: Need help dressing  */
/*     ADQ26@5 Does the person need the help of */
/*     another person with dressing?            */
  @1590 EWALK2H  2. /* ADQ: Need help walking  */
/*     ADQ26@6 Does the person need the help of */
/*     another person with walking?             */
  @1593 EEATHELP 2. /* ADQ: Need help eating    */
/*     ADQ26@7 Does the person need the help of */
/*     another person with eating?              */
  @1596 ETOILETH 2. /* ADQ: Need help using or getting to the toilet */
/*     ADQ26@8 Does the person need the help of another person with  */
/*     using or getting to the toilet?                               */
  @1599 EMONEYH  2. /* ADQ: Need help keeping track of money and bills */
/*     ADQ26@9 Does the person need the help of another person with    */
/*     keeping track of money and bills?                               */
  @1602 EMEALSH  2. /* ADQ: Need help preparing meals */
/*     ADQ26@10 Does the person need the help of      */
/*     another person with preparing meals?           */
  @1605 EHWORKH  2. /* ADQ: Need help doing light housework */
/*     ADQ26@11 Does the person need the help of another    */
/*     person with doing light housework such as washing    */
/*     dishes or sweeping a floor?                          */
  @1608 EMEDH    2. /* ADQ: Need help taking right amount of medicine   */
/*     ADQ26@12 Does the person need the help of another person with    */
/*     taking the right amount of prescribed medicine at the right time?*/

/* The fololwing questions identify specific conditions. */
  @1640 ECOND1   2. /* ADQ: First condition causing difficulty */
/*     ADQ32@1 I have recorded that the person has difficulty  */
/*     with certain activities.  Which condition or conditions */
/*     cause these difficulties?                               */
  @1643 ECOND2   2. /* ADQ: Second condition causing difficulty */
/*     ADQ32@2 I have recorded that the person has difficulty   */
/*     with certain activities.  Which condition or conditions  */
/*     cause these difficulties?                                */
  @1645 ECOND3   2. /* ADQ: Third condition causing difficulty */
/*     ADQ32@3 I have recorded that the person has difficulty  */
/*     with certain activities.  Which condition or conditions */
/*     cause these difficulties?                               */
  @1654 EMOTORV  2. /* ADQ: Condition is result of a motor vehicle accident */
/*     ADQ34 Is this condition the result of a motor vehicle accident?      */
  @1657 EMAIN1   2. /* ADQ: Main reason for difficulty        */
/*     ADQ35@1 Which of the conditions that you mentioned     */
/*     do you consider to be the main reason for the person's */
/*     difficulties?                                          */
  @1660 TYEAR1   4. /* ADQ: Year when main condition first began */
/*     ADQ36@YR When did (name of [main] condition) first begin  */
/*     to bother the person?                                     */
  @1665 EMONTH1  2. /* ADQ: Month when main condition first began */
/*     ADQ36B@MN Do you know what month?                          */
  @1668 EHAD5M   2. /* ADQ: Had this condition for at least five months */
/*     ADQ37 Has the person had this condition for at least five months?*/
  @1670 ELAST12M 2. /* ADQ: Condition expected to last 12+ months */
/*     ADQ38 Is this condition expected to last for at least 12   */
/*     more months? (Note: The person is asked this question only */
/*     if they have NOT had this condition for at least 5 months.)*/

/* The following concern Mental Disability conditions. */
  @1673 ELDIS    2. /* ADQ: Learning disability */
/*     ADQ39@1 Does the person have a learning  */
/*     disability such as dyslexia?             */
  @1676 EMR      2. /* ADQ: Mental retardation         */
/*     ADQ39@2 Does the person have mental retardation?*/
  @1679 EDEVDIS  2. /* ADQ: Developmental disability */
/*     ADQ39@3 Does the person have a developmental  */
/*     disability such as autism or cerebral palsy?  */
  @1682 EALZ     2. /* ADQ: Alzheimer's disease  */
/*     ADQ39@4 Does the person have Alzheimer's  */
/*     disease or any other serious problem with */
/*     confusion or forgetfulness?               */
  @1685 EOTHERM  2. /* ADQ: Other mental or emotional condition */
/*     ADQ39@5 Does the person have any other mental or         */
/*     emotional condition?                                     */
  @1688 EANXIOUS 2. /* ADQ: Frequently depressed or anxious */
/*     ADQ40 Is the person frequently depressed or anxious? */
  @1691 ESOCIAL  2. /* ADQ: Trouble getting along with other people */
/*     ADQ41@1 Does the person have a lot of trouble getting along  */
/*     with other people and making and keeping relationships?      */
  @1694 ECTRATE  2. /* ADQ: Trouble concentrating          */
/*     ADQ41@2 Does the person have a lot of trouble       */
/*     concentrating long enough to finish everyday tasks? */
  @1697 ECOPE    2. /* ADQ: Trouble coping with stresses    */
/*     ADQ41@3 Does the person have a lot of trouble coping */
/*     with day-to-day stresses?                            */
  @1700 EINTRFER 2. /* ADQ: Ability to manage everyday activities */
/*     ADQ42 During the past 12 months, did the problems just     */
/*     mentioned seriously interfere with the person's ability to */
/*     manage everyday activities?                                */

/* The following are work related limitations/disabilities. */
  @1703 EJOBDIF  2. /* ADQ: Physical/mental condition and job difficulty */
/*     ADQ43 Does the person have a long-lasting physical or mental      */
/*     condition that has made it difficult to remain employed or to     */
/*     find a job?                                                       */
  @1706 EJOBCANT 2. /* ADQ: Health or condition preventing working */
/*     ADQ44 Does the person's health or condition prevent the     */
/*     person from working at a job or business?                   */
  @1709 EHWRKDIF 2. /* ADQ: Condition limiting the kind/amount of housework */
/*     ADQ45 Does the person have a physical, mental, or other    */
/*     health condition that limits the kind or amount of work    */
/*     the person can do around the house?                        */
  @1712 EHWRKNO 2. /* ADQ: Health/condition prevents doing any housework */
/*     ADQ45 Does the person's health or condition completely prevent    */
/*     the person from doing work around the house?                      */

/* The fololwing questions identify work-related conditions. */
  @1715 ECONDW1 2. /* ADQ: First condition causing limitation in working */
/*     ADQ47@1 I have recorded that the person has a limitation in       */
/*     working. Which condition or conditions cause this limitation?     */
  @1718 ECONDW2 2. /* ADQ: Second condition causing limitation in working */
/*     ADQ47@2 I have recorded that the person has a limitation in        */
/*     working. Which condition or conditions cause this limitation?      */
  @1720 ECONDW3 2. /* ADQ: Third condition causing limitation in working */
/*     ADQ47@3 I have recorded that the person has a limitation in       */
/*     working. Which condition or conditions cause this limitation?     */
  @1722 EMAIN2  2. /* ADQ: Main reason for work limitation        */
/*     ADQ48@1 Which of the conditions that you mentioned do you  */
/*     consider to be the main reason for the person's limitation?*/
  @1725 EAPPLYSS 2. /* ADQ: Social Security disability benefits */
/*     ADQ49 In the last 12 months, has the person applied for  */
/*     Social Security disability benefits for himself/herself? */
  ;

/* Select only the adults.                                    */
/* Adult disability variables have values ONLY when EPADUNV=1 */
if EPADUNV eq 1;

/* The codebook defines an "activity limitation" (i.e.,   */
/* having difficulty with certain activities) as follows: */
/* (note: this set not currently used to define ADISAB)   */
 actlim=0;
 if (ECANE    eq 1 or EWCHAIR  eq 1 or EHEARAID eq 1 or 
     ESEEDIF  eq 1 or EHEARDIF eq 1 or ESPEECHD eq 1 or 
     EDIF10   eq 1 or EDIF25   eq 1 or EPUSHD   eq 1 or 
     ESTANDD  eq 1 or ESITD    eq 1 or ESTOOPD  eq 1 or 
     EREACHD  eq 1 or EGRASPD  eq 1 or ESTAIRSD eq 1 or 
     EWALKD   eq 1 or ETELED   eq 1 or EINDIF   eq 1 or 
     EOUTDIF  eq 1 or EBEDDIF  eq 1 or EBATHDIF eq 1 or 
     EDRESSD  eq 1 or EWALK2D  eq 1 or EEATDIF  eq 1 or 
     ETOILETD eq 1 or EMONEYD  eq 1 or EMEALSD  eq 1 or 
     EHWORKD  eq 1 or EMEDD    eq 1) 
 then actlim=1;

/* Define FUNCLIM exactly as it was defined for 1993 SIPP.*/
 funclim=0;
 if (ECANE    eq 1 or EWCHAIR  eq 1 or ESEEDIF  eq 1 or 
     EHEARDIF eq 1 or ESPEECHD eq 1 or EDIF10   eq 1 or 
     ESTAIRSD eq 1 or EWALKD   eq 1 or ETELED   eq 1 or 
     EINDIF   eq 1 or EOUTDIF  eq 1 or EBEDDIF  eq 1 or 
     EBATHDIF eq 1 or EDRESSD  eq 1 or EWALK2D  eq 1 or 
     EEATDIF  eq 1 or ETOILETD eq 1 or EMONEYD  eq 1 or 
     EMEALSD  eq 1 or EHWORKD  eq 1 or EJOBDIF  eq 1 or 
     EHWRKDIF eq 1)
 then funclim=1;

/* Define a severe disability (exactly as for 1993 SIPP) */
 sevlim=0;
 if (ECANE6   eq 1 or ESEENOT  eq 2 or EHEARNOT eq 2 or
     ESPEECHC eq 2 or ECANT10  eq 2 or ESTAIRSC eq 2 or
     EWALKC   eq 2 or ETELEC   eq 2 or EINHELP  eq 1 or
     EOUTHELP eq 1 or EBEDHELP eq 1 or EBATHH   eq 1 or
     EDRESSH  eq 1 or EWALK2H  eq 1 or EEATHELP eq 1 or
     ETOILETH eq 1 or EMONEYH  eq 1 or EMEALSH  eq 1 or
     EHWORKH  eq 1 or EJOBCANT eq 1 or EHWRKNO  eq 1)
 then sevlim=1;

 if (sevlim=0) and (funclim=1) then modlim=1;
 else modlim=0;

/* Recode no=2 and na=-1 to be no=0 so can sum variables */
/* to obtain number of limitations                       */
 array disvars{22} 
     ECANE     EWCHAIR   ESEEDIF  
     EHEARDIF  ESPEECHD  EDIF10    
     ESTAIRSD  EWALKD    ETELED 
     EINDIF    EOUTDIF   EBEDDIF   
     EBATHDIF  EDRESSD   EWALK2D   
     EEATDIF   ETOILETD  EMONEYD   
     EMEALSD   EHWORKD   EJOBDIF 
     EHWRKDIF; 
 do i=1 to 22;
    if disvars{i} ne 1 then disvars{i}=0;
 end;

 sumvar= 
    (ECANE    +EWCHAIR  +ESEEDIF  
    +EHEARDIF +ESPEECHD +EDIF10  
    +ESTAIRSD +EWALKD   +ETELED 
    +EINDIF   +EOUTDIF  +EBEDDIF 
    +EBATHDIF +EDRESSD  +EWALK2D  
    +EEATDIF  +ETOILETD +EMONEYD
    +EMEALSD  +EHWORKD  +EJOBDIF 
    +EHWRKDIF); 
 if (sumvar>1) then plus2lim=1;
 else plus2lim=0;

 if (plus2lim=0) and (funclim=1) then onelim=1;
 else onelim=0;

/* Define limitation with an ADL (Activity of Daily Living)  */
/* (uses the difficulties explicitly listed by Lara for 1993)*/
 adllim=0;
 if (ESEEDIF  eq 1 or EHEARDIF eq 1 or ESPEECHD eq 1 or
     EINDIF   eq 1 or EBEDDIF  eq 1 or EBATHDIF eq 1 or
     EDRESSD  eq 1 or EEATDIF  eq 1 or ETOILETD eq 1)
 then adllim=1;

/* Define an IADL (Instrumental Activity of Daily Living) */
/* limitation as something that is not a difficulty with  */
/* an ADL but is a Functional Limitation - it does not    */
/* limit the kind or amount of work that can be done on a */
/* job or around the house.                               */
 iadllim=0;
 if adllim eq 0 and funclim eq 1 and
   (EJOBDIF ne 1 and EHWRKDIF ne 1)
 then iadllim=1;

/* Define a Work Limitation */
 worklim=0;
 if EJOBDIF eq 1 then worklim=1;

 if worklim=0 and funclim=1 then notwork=1;
 else notwork=0;

*define the broadest definition of disability, following Powers
 and McNeil;
 if (funclim=1 or sevlim=1 or modlim=1 or plus2lim=1 or onelim=1 or
  adllim=1 or iadllim=1 or worklim=1) then adisab=1;
 else adisab=0;

 syear='96';
 id1='000000000000';
 id1=PPID;
 id3='0000';
 id3=PPPNUM;
 sunique=syear||id1||id3;
run;

proc means;

proc freq;
tables adllim*iadllim*worklim;
tables EJOBDIF EHWRKDIF;
tables funclim*worklim*notwork;
tables EAPPLYSS*funclim;
tables age*EAPPLYSS;
tables age*funclim;


data disab.adisab96;
 set adults;
 keep PPID ROT PPPNUM funclim sevlim modlim 
 plus2lim onelim adllim iadllim worklim adisab sunique;

run;
