options linesize=80 nocenter pagesize=66;
/* Reads 1991 SIPP data: Finds better values for "Highest Grade  */
/* Completed" and "Enrolled During Month"; converts to 1 record  */
/* per person per month (from one record per person); write new  */
/* file with these revised values (plus grade enrolled in).      */

%let SIPPYEAR=91;  /* Year when ROT=1 (for computing month/year) */
%let NQ=8;               /* Number of Quarters in this SIPP file */
%let NM=32;                /* Number of Months in this SIPP file */

/* Other things that must be changed to convert to another SIPP: */
/* - name of input data                                          */
/* - value of LRECL for input file                               */
/* - column numbers of all the input variables                   */

%macro convQtoM(name);
 %do k=&NM %to 1 %by -1;
   %let j = %eval((&k + 3)/4);
  &name&k = &name&j;
 %end;
%mend convQtoM;

libname yyy '';
data test;
/* filename xxx PIPE 'gunzip -c /files2/ldshore/sipp/1991/da2036.gz'; */
 filename xxx 'c:\SIPP_data\sipp91fp.dat';
 infile xxx lrecl=12601 missover;
 input
 @7    rot 1.
 @8    ppid 9.
 @17   ppentry 2.
 @19   ppnum 3.
 @1240 (rrp1-rrp&NM) (1.)    /* When RRP=0, no data should exist */
 @1272 (age1-age&NM) (2.)
 @1784 (higrad1-higrad&NQ) (2.)
 @1800 (grdcmp1-grdcmp&NQ) (1.)
 @2226 (attsch1-attsch&NQ) (1.)
 @2234 (enrmth1-enrmth&NM) (1.)
 @2266 (edlevl1-edlevl&NQ) (2.)
;

/* length sunique $ 18; */
/* sunique=put(&SIPPYEAR,z2.)||put(ppid,z9.)||put(ppentry,z3.)||
         put(ppnum,z4.); */

syear=put(&SIPPYEAR,z2.);
id1='000000000';
id1=ppid;
id2='00';
id2=ppentry;
id3='000';
id3=ppnum;
sunique=syear||id1||id2||id3; 

 array higrad{&NQ} higrad1-higrad&NQ;
 array grdcmp{&NQ} grdcmp1-grdcmp&NQ;
 array attsch{&NQ} attsch1-attsch&NQ;
 array edlevl{&NQ} edlevl1-edlevl&NQ;
 array enrmth{&NM} enrmth1-enrmth&NM;
 drop ppid ppentry ppnum ;
/* XEDLVLs are new EDLEVLs, "better" than original */
 array xedlvl{&NQ} xedlvl1-xedlvl&NQ;
/* HYGRADs are new HIGRADs, modified by XEDLEL */
 array hygrad{&NQ} hygrad1-hygrad&NQ;
/* INSCHLs are new ENRMTHs, "better" than original */
 array xinschl{&NM} inschl1-inschl&NM;

/* Create a  quarterly RRP value for all the quarters */
 array rrpq{&NQ} rrpqt1-rrpqt&NQ;
 array rrp{&NM} rrp1-rrp&NM;
 do i=1 to &NQ;
  rrpq{i}=1; /* RRP for all 4 months of a quarter */
  j1=(i-1)*4+1;
  j2=j1+1;
  j3=j1+2;
  j4=j1+3;
  if (rrp{j1} eq 0 and rrp{j2} eq 0 and rrp{j3} eq 0 and rrp{j4} eq 0)
   then rrpq{i}=0;
 end;
/* Check if there are any HIGRAD values for quarters with non-zero RRP */
 anyhigr=0;
 do i=1 to &NQ;
  if higrad{i} ne 0 and rrpq{i} ne 0 then anyhigr=1;
 end;
/* If there was at least one quarter with a HIGRAD value, delete */
/* all HIGRADs from RRP=0 quarters                               */
 if anyhigr eq 1 then
  do i=1 to &NQ;
   if rrpq{i} eq 0 then higrad{i}=0;
  end;
 drop anyhigr rrpqt1-rrpqt&NQ;


/* Note differences in coding for HIGRAD, ED-LEVEL and our recoding*/
/*  college yr.  recoded HIGRAD  actual HIGRAD  actual ED_LEVEL    */
/*  -----------  --------------  -------------  ---------------    */
/*      1              13              21              3           */
/*      2              14              22              4           */
/*      3              15              23              5           */
/*      4              16              24              6           */
/*      5              17              25              7           */
/*      6              18              26              8           */


 do i=1 to &NQ;
/* Recode education levels for HIGRAD:    */
/*      21->13, 22->14, 23->15 ... 26->18 */
  if higrad{i} gt 12 then higrad{i}=higrad{i}-8;
/* Recode original HIGRAD (highest ATTENDED) downward if not     */
/* completed.  This is the same thing done previously, and       */
/* makes the recoded HIGRAD now be "highest grade COMPLETED".    */
  if grdcmp{i} ne 1 and higrad{i} gt 0 then higrad{i}=higrad{i}-1;
 end;

/* Determine whether the data on "attending school" is believable. */
/* Check if                                                        */
/*  (1) "enrolled in school during the quarter"                    */
/*  (2) "enrolled at what level or grade during the quarter" and   */
/*  (3) "enrolled during the month" for the 4 months of the quarter*/
/* all agree that the person was or was not in school.             */
/* If 2 of the 3 agree, assume that is true - reset data if needed.*/

 chgedlvl=0; /* CHGEDLVL=0 => EDLEVL NOT changed for this person */
 do i=1 to &NQ;
/* CHECK and CHECK2 help determine if person was InSchool or not: */
/*  - if CHECK=1: ENRMTH => InSchool during quarter               */
/*  - if CHECK2=1: 2 of 3 vars => NOT InSchool during quarter     */
 check2=0;
 check=0;
 do j=1 to 4;
  k=((i-1)*4)+j;
  xinschl{k}=enrmth{k};  /* Copy "enroll month" data to output */
  if enrmth{k} eq  1 then check=1; /* enrolled in month */
 end;

/* If ENRMTH and ATTSCH both indicate "in school" or             */
/* if ENRMTH and EDLEVL both indicate "in school", don't change. */
 if check eq 1 and (attsch{i} in(1,2) or edlevl{i} ne 0) 
     then goto BOTTOM;

/* If ENRMTH and ATTSCH both indicate "not in school" or           */
/* if ENRMTH and EDLEVL both indicate "not in school", don't change*/
/* the INSCHL values but DO change XEDLVL because cannot trust it. */
 if check eq 0 and (attsch{i} in(0,3) or edlevl{i} eq 0) then
   do;
    check2=1;
    goto BOTTOM;
   end;

/* If ATTSCH and EDLEVL both indicate "in school" (but ENRMTH      */
/* doesn't), change value of new variables (i.e., INSCHL) to show  */
/* "in school" for all 4 months in the quarter.                    */
 if attsch{i} in(1,2) and edlevl{i} ne 0 then
 do j=1 to 4;
  k=((i-1)*4)+j;
  xinschl{k}=1;
 end;

/* If ATTSCH and EDLEVL both indicate "not in school" (but ENRMTH  */
/* does), change value of new variables (i.e., INSCHL) to show     */
/* "not in school" for all 4 months in the quarter.                */
 if attsch{i} in(0,3) and edlevl{i} eq 0 then
 do j=1 to 4;
  k=((i-1)*4)+j;
  xinschl{k}=0;
 end;

BOTTOM:
/* XEDLVL is EDLEVL modified to 0 if no other variable implies   */
/* that the person was InSchool.                                 */
 xedlvl{i}=edlevl{i};
 if check2 eq 1 then
   do;
   xedlvl{i}=0;
/* CHGEDLVL=1 indicates EDLVL was changed for this person */
   if edlevl{i} ne 0 then chgedlvl=1;
   end;
 end;  /* END OF LOOP "do i" to check and modify "in school" data. */


/* Copy modified EDLEVL to HYGRAD for college years only, and      */
/* recode to the same scale as the recoded HIGRAD used in the data.*/
 do i =1 to &NQ;
 if xedlvl{i} ge 3 and xedlvl{i} le 8 then /* use college yrs only */
  do;
  hygrad{i}=xedlvl{i}+10; /* recode to match HIGRAD coding */
  end;
 else hygrad{i}=0;
 end;

/* If people have sequences that decrease, or increase more than 1 */
/* yr, remove them from the new HYGRAD since they are questionable.*/
/* Find decreases or jumps. */
 last=hygrad{1};
 do i=2 to &NQ;
 if hygrad{i} ne 0 then
  do;
  if last gt hygrad{i} then decreas=1;
  if last ne 0 and hygrad{i}-last gt 1 then jump=1;
  last=hygrad{i};
  end;
 end;
/* If any decreases or jumps, don't trust data: reset to zero */
 if decreas eq 1 or jump eq 1 then
  do i=1 to &NQ;
  hygrad{i}=0; /* Reset EDLEVL to 0 */
  do j=1 to 4;
   k=((i-1)*4)+j;
   xinschl{k}=0; /* Reset INSCHL to show "not in school" */
  end;
  end;

/* Set up arrays to hold frequency counts of the various HYGRAD */
/* values for a person (can be up to &NQ values) plus the values. */
 array hyfreq{&NQ} hyfreq1-hyfreq&NQ;
 array hyvalu{&NQ} hyvalu1-hyvalu&NQ;
 hyvalu{1}=hygrad{1};
 hyfreq{1}=1;
 numval=1; /* number of different HYGRAD values found */
 do i=2 to &NQ;
   hyvalu{i}=.;
   hyfreq{i}=0;
   found=0;
   do j=1 to i;
     if hygrad{i} eq hyvalu{j} then
       do;
          hyfreq{j}=hyfreq{j}+1;
          found=1;
       end;
   end;
   if found ne 1 then
     do;
       numval=numval+1;
       hyvalu{numval}=hygrad{i};
       hyfreq{numval}=1;
     end;
 end;



/* ------------------------------------------------------- */
/* Loop through and try to create "better" values in HGRAD */
 array hgrad{&NQ} hgrad1-hgrad&NQ;
 do i=1 to &NQ;
  hgrad{i}=higrad{i}; /* Start with existing HIGRAD value */
 end;

/* Check to see if there is any EDLEVL info (&NQ zeros => none) */
 if hyvalu(1) eq 0 and hyfreq(1) eq &NQ then goto NOEDLVL;

/* If there is only one quarter with EDLEVL info and if that  */
/* value is more than 1 grade bigger than the highest HIGRAD  */
/* value, discard it as a coding mistake.                     */
/* Find highest HIGRAD value (highest grade completed). */
 highhigr=max(of higrad1-higrad&NQ);
/* Find highest EDLEVL value (highest grade enrolled in) */
/* up to a maximum of college yr 6.                      */
 highedlv=max(of hygrad1-hygrad&NQ);
 if hyvalu(1) eq 0 and hyfreq(1) eq &NQ-1 and highhigr ne 0
  and hyvalu(2) gt highhigr+1 then
   do;
     /* Find which quarter has HYGRAD value and reset to 0 */
     do i=1 to &NQ;
     if hygrad{i} ne 0 then
      do;
      hygrad{i}=0; /* Reset EDLEVL to 0 */
      do j=1 to 4;
       k=((i-1)*4)+j;
       xinschl{k}=0; /* Reset INSCHL to show "not in school" */
      end;
      end;
     end;
   goto NOEDLVL;
   end;


/* -------------------------------------------------------- */
/* This part of code handles people that have at least some */
/* EDLEVL information available for them.                   */

/* Get rid of 1-quarter miscodings:                                */
/* If quarter before and after differ by no more than 1 grade but  */
/* grade in middle quarter is VERY different (currently set to a   */
/* value of 5, which is arbitrary and can be changed if desired)   */
/* its probably due to a coding error. Reset it to match the grade */
/* in the "before" quarter.                                        */
 do k=1 to &NQ-2;
   if hgrad{k} ne 0 and
      (hgrad{k} eq hgrad{k+2} or hgrad{k} eq hgrad{k+2}-1) and
      abs(hgrad{k+1}-hgrad{k}) gt 5 then /* Note: 5 is the diff */
      hgrad{k+1}=hgrad{k};
 end;

/* Try to "fix" first &NQ-1 quarters by merging in data on the */
/* grade they attended, if they did attend school in a quarter.*/
/* Start by finding the next 2 grades they attended (in this   */
/* quarter and in later quarters).                             */
 do i=1 to &NQ-1;
  do k=i to &NQ;
    nonz1q=k; /* NONZ1Q is Quarter of 1st nonzero HYGRAD if exists */
    nonz1v=hygrad{nonz1q};  /* NONZ1V is 1st non-zero HYGRAD Value */
    if nonz1v ne 0 then goto gotnon0;
  end;
gotnon0:
  nonz2v=0;
  if nonz1q lt &NQ then
  do j=(nonz1q+1) to &NQ;
    nonz2q=j; /* NONZ2Q is Quarter of NEXT nonzero HYGRAD if exist */
    nonz2v=hygrad{nonz2q}; /* NONZ2V is NEXT non-zero HYGRAD Value */
    if nonz2v ne 0 then goto got2non0;
  end;
got2non0:

/* If they were attending school this quarter, the highest     */
/* grade completed must be either the grade they attended (if  */
/* they completed it) OR the previous grade (if they didn't    */
/* finish the grade they were attending).  Use the larger of   */
/* the recorded HIGRAD (up to a maximum of the same grade they */
/* attended) or else 1 less than grade attended.               */
   if nonz1q eq i then
    if nonz1v eq nonz2v then hgrad{i}=nonz1v-1;
    else
     do;
/*   Cannot be higher grade than the grade attended. */
     if hgrad{i} gt nonz1v then hgrad{i}=nonz1v;
     hgrad{i}=max(hgrad{i},nonz1v-1);
     end;

/* If there is no HYGRAD value for THIS quarter, but the next  */
/* nonzero HYGRAD shows the person was attending a lower grade */
/* in school, then the recorded HIGRAD must be incorrect       */
/* (too high) so reset it. They must have at least finished    */
/* the grade previous to the one being attended.               */
   if hygrad{i} eq 0 and nonz1v lt hgrad{i} and nonz1v ne 0 then
    hgrad{i}=nonz1v-1;

/* If there is no HYGRAD value for THIS quarter, and the next  */
/* nonzero HYGRAD shows person was attending a higher grade    */
/* in school (and no following grade information available),   */
/* then this grade level should be AT LEAST the minimum of the */
/* preceeding quarter's grade level (not counting zeros) and   */
/* the "next grade attended" -1                                */
  if i ge 2 and hygrad{i} eq 0 and nonz1v ne 0 and nonz2v eq 0 and
    nonz1v gt hgrad{i}+1  and hgrad{i-1} ne 0  then
    do;
    if hgrad{i} eq 0 then
      hgrad{i} = min(hgrad{i-1},nonz1v-1);
    else
      if hgrad{i} lt min(hgrad{i-1},hgrad{i},nonz1v-1)
      then hgrad{i} = min(hgrad{i-1},hgrad{i},nonz1v-1);
    end;

/* If there is no HYGRAD value for THIS quarter, but the next  */
/* two nonzero HYGRADs shows the person was attending the same */
/* grade in school for both of those quarters (or the next     */
/* grade and 1 grade beyond that) then they can have finished  */
/* only the grade previous to nonz1v.                          */
   if hygrad{i} eq 0 and nonz1v ne 0  and nonz2v ne 0
    and (nonz1v eq nonz2v or nonz1v eq nonz2v-1) then
    hgrad{i}=min(hgrad{i},nonz1v-1);

/* If the previous HIGRAD value was bigger than this quarter & */
/* if there is no HYGRAD value for THIS quarter, and the next  */
/* nonzero HYGRAD shows the person was attending higher grade  */
/* in school, then the recorded HIGRAD might be incorrect      */
/* (too low) so check it.  If the previous HIGRAD is the same  */
/* as the next HYGRAD (or one less than it in case they didn't */
/* finish that grade) then  reset this to match previous.      */
  if i ge 2 and hgrad{i-1} gt hgrad{i} and
    (hgrad{i-1} eq hygrad{i+1} or hgrad{i-1} eq hygrad{i+1}-1)
    then hgrad{i}=hgrad{i-1};

/* If this and all following HYGRAD values are zero, use       */
/* bigger of this HIGRAD or the highest grade enrolled in - 1  */
/* or highest grade enrolled in (if next HIGRAD equals that).  */
  if i ge 2 and nonz1v eq 0 and nonz2v eq 0 then
   do;
   if hgrad{i+1} eq highedlv and hgrad{i} lt highedlv-1 then
     hgrad{i}=highedlv;
   else
     hgrad{i}=max(hgrad{i-1},hgrad{i},highedlv-1);
/* If original HIGRAD is at least as big as highedlv, use it*/
   if higrad{i} ge highedlv then hgrad{i}=higrad{i};
/* If this value is less than the one before AND less that the */
/* one after, it must be an error - reset to match one before. */
   if hgrad{i} ne 0 and hgrad{i-1} ne 0 and hgrad{i+1} ne 0
     and hgrad{i} lt hgrad{i-1} and hgrad{i} lt hgrad{i+1}
     then hgrad{i}=hgrad{i-1};
   end;
 end;

/* Finished "fixing" first &NQ-1 quarters, now do %NQth. */
 hgrad{&NQ}=higrad{&NQ}; /* Start with existing HIGRAD value */
/* If HYGRAD exists, use bigger of HYGRAD-1 (might not finish) or */
/* HIGRAD (up to a maximum of previous HGRAD+1)                   */
 if hygrad{&NQ} ne 0 then
 do;
   hgrad{&NQ}=max(hgrad{&NQ},hygrad{&NQ}-1);
   if hgrad{&NQ-1} le hygrad{&NQ}-1 and hgrad{&NQ-1} ne 0
     then hgrad{&NQ}=min(hgrad{&NQ-1}+1,hgrad{&NQ});
 end;

/* If HYGRAD shows they were attending the first year of college  */
/* but the previous HIGRAD shows a grade lower than finishing     */
/* high school, set this to show they did finish high school.     */
 if hygrad{&NQ} eq 13 and hgrad{&NQ} lt 12 then hgrad{&NQ}=12;

/* If still zero, or less than previous, use previous quarter. */
 if hgrad{&NQ} eq 0 or hgrad{&NQ} lt hgrad{&NQ-1} 
     then hgrad{&NQ}=hgrad{&NQ-1};


/* Check to see if people with no decreases of jumps in  */
/* HIGRAD got worse (i.e. got decreases or jumps) after  */
/* adding the EDLEVL data.  If so, remove EDLEVL info.   */
/* Step 1: Find decreases or jumps Before adding EDLEVL. */
 lastb=higrad{1};
 do i=2 to &NQ;
 if higrad{i} ne 0 then
  do;
  if lastb gt higrad{i} then decrsb=1;
  if lastb ne 0 and higrad{i}-lastb gt 1 then jumpb=1;
  lastb=higrad{i};
  end;
 end;
/* Step 2: Find decreases or jumps After adding EDLEVL. */
 lasta=hgrad{1};
 do i=2 to &NQ;
 if hgrad{i} ne 0 then
  do;
  if lasta gt hgrad{i} then decrsa=1;
  if lasta ne 0 and hgrad{i}-lasta gt 1 then jumpa=1;
  lasta=hgrad{i};
  end;
 end;
/* Step 3: If any decreases or jumps added by EDLEVL data */
/* don't trust data: reset to original values.            */
 if decrsb ne 1 and jumpb ne 1 and (decrsa eq 1 or jumpa eq 1) then
  do i=1 to &NQ;
  hgrad{i}=higrad{i}; /* Reset to original values */
  end;

/* After adding HYGRAD values, try to fix remaining problems. */


/* ------------------------------------------------------------ */
/* This part of code handles people with no EDLEVL information. */
NOEDLVL:

/* Set up arrays to hold frequency counts of the various HIGRAD */
/* values for a person (can be up to &NQ values) plus the values*/
 array hifreq{&NQ} hifreq1-hifreq&NQ;
 array hivalu{&NQ} hivalu1-hivalu&NQ;
 hivalu{1}=higrad{1};
 hifreq{1}=1;
 numval=1; /* number of different HIGRAD values found */
 do i=2 to &NQ;
   hivalu{i}=.;
   hifreq{i}=0;
   found=0;
   do j=1 to i;
     if higrad{i} eq hivalu{j} then
       do;
          hifreq{j}=hifreq{j}+1;
          found=1;
       end;
   end;
   if found ne 1 then
     do;
       numval=numval+1;
       hivalu{numval}=higrad{i};
       hifreq{numval}=1;
     end;
 end;

/* Find next non-zero value (beyond first quarter). */
 do k=2 to &NQ;
  qnonz1=k;
  nextnonz=hgrad(qnonz1); /* NEXTNONZ is 1st non-zero HGRAD value */
  if nextnonz ne 0 then goto n0hgrad;
 end;
n0hgrad:
/* See if there is another non-zero HGRAD beyond one just found */
 nxt2nonz=0;
 if qnonz1 lt &NQ then
 do l=(qnonz1+1) to &NQ;
  nxt2nonz=hgrad{l}; /* NXT2NONZ is 2nd non-zero HGRAD (if exists) */
  if nxt2nonz ne 0 then goto n0hgrad2;
 end;
n0hgrad2:

/* If higher grade completed in 1st quarter than in next non-zero */
/* quarter, reset value of 1st quarter to be the more frequently  */
/* occurring value (not counting 0 or big jumps in value which    */
/* probably indicate coding error).                               */
 if hgrad(1) gt nextnonz and nextnonz ne 0
   and abs(nextnonz-hgrad{1}) lt 7 then
  do;
   freq1=0; freq2=0;
   do j=1 to numval;
    if hgrad(1) eq hivalu{j} then freq1=hifreq{j};
    if nextnonz eq hivalu{j} then freq2=hifreq{j};
   end;
   /* If next is more frequent, use that value. */
   if freq2 gt freq1 then hgrad(1)=nextnonz;
   /* If same frequency, use whichever is smaller. */
   if freq2 eq freq1 then hgrad(1)=min(hgrad(1),nextnonz);
  end;

/* If 1st quarter is zero and next non-zero quarter is bigger */
/* than 2nd non-zero quarter, reset zero value in 1st quarter */
/* to be more frequently occurring value (not counting 0 or   */
/* big jumps in value which probably indicate coding error).  */
 if hgrad(1) eq 0 and nextnonz ne 0 and nxt2nonz ne 0 and
    nextnonz gt nxt2nonz and abs(nextnonz-nxt2nonz) lt 5 then
  do;
   freq1=0; freq2=0;
   do j=1 to numval;
    if nextnonz eq hivalu{j} then freq1=hifreq{j};
    if nxt2nonz eq hivalu{j} then freq2=hifreq{j};
   end;
   /* Use whichever of those 2 values is most frequent. */
   if freq1 gt freq2 then hgrad(1)=nextnonz;
    else hgrad(1)=nxt2nonz;
   /* If same frequency, use whichever is smaller. */
   if freq2 eq freq1 then hgrad(1)=min(nextnonz,nxt2nonz);
  end;

/* If 1st non-zero value is very small (less than 8) and     */
/* has frequency of 1 and next non-zero value is at least 6  */
/* grades higher and has frequency > 1, assume 1st is coding */
/* error and reset it to match 2nd non-zero value.           */
/* Find first and second non-zero value. */
 do k=1 to &NQ;
  qnonz1=k;
  fstnonz=hgrad(qnonz1); /* FSTNONZ is 1st non-zero HGRAD value   */
  if fstnonz ne 0 then goto n1;
 end;
n1:
/* See if there is another non-zero HGRAD beyond one just found */
 secnonz=0;
 if qnonz1 lt &NQ then
 do l=(qnonz1+1) to &NQ;
  secnonz=hgrad{l}; /* SECNONZ is 2nd non-zero HGRAD (if exists) */
  if secnonz ne 0 then goto n2;
 end;
n2:
 if fstnonz ne 0 and secnonz ne 0 then 
/* do this only if 2 non-zeros */
 do;
  if fstnonz lt 8 and secnonz gt (fstnonz+6) then
/* Get frequencies of both values */
  do;
    freq1=0; freq2=0;
    do j=1 to numval;
     if fstnonz eq hivalu{j} then freq1=hifreq{j};
     if secnonz eq hivalu{j} then freq2=hifreq{j};
    end;
  if freq1 eq 1 and freq2 gt 1 then hgrad{qnonz1}=secnonz;
  end;
 end;

/* If 1st non-zero value is two or more grades less than 2nd */
/* non-zero value, and if 1st non-zero value has a frequency */
/* of 1 and next non-zero value has frequency > 1, assume 1st*/
/* is coding error and reset it to match 2nd non-zero value. */
/* Use FSTNONZ (in quarter QNONZ1) and SECNONZ found above.  */
 if fstnonz ne 0 and secnonz ne 0 then 
/* do this only if 2 non-zeros */
 do;
  if secnonz-fstnonz gt 1 then
  do;
/* Get frequencies of both values */
    freq1=0; freq2=0;
    do j=1 to numval;
     if fstnonz eq hivalu{j} then freq1=hifreq{j};
     if secnonz eq hivalu{j} then freq2=hifreq{j};
    end;
/* If needed, reset 1st to match 2nd. */
  if freq1 eq 1 and freq2 gt 1 then hgrad{qnonz1}=secnonz;
  end;
 end;

/* Try to fix any remaining zeros. */
 do i=1 to &NQ-1;
/* Find first nonzero HGRAD value */
  do k=i to &NQ;
    temp3=hgrad{k};  /* Find first non-zero HGRAD value if exists */
    if temp3 ne 0 then goto gotnon0h;
  end;
gotnon0h:
 if hgrad{i} eq 0 then
   if i eq 1 then hgrad{i}=temp3;
     else hgrad{i}=hgrad{i-1};
 end;

/* Get rid of 1-quarter differences/miscodings:                    */
/* If no more that 1 grade different in before and after quarters  */
/* but middle not same as either of them, reset middle to value of */
/* "before" qtr.                                                   */
 do i=1 to &NQ-2;
   if hgrad{i} ne 0 and
      (hgrad{i} eq hgrad{i+2} or hgrad{i} eq hgrad{i+2}-1) and
      (hgrad{i+1} ne hgrad{i} and hgrad{i+1} ne hgrad{i+2}) then
      hgrad{i+1}=hgrad{i};
 end;

/* If &NQth still zero or less than previous, use previous quarter*/
 if hgrad{&NQ} eq 0 or hgrad{&NQ} lt hgrad{&NQ-1} 
     then hgrad{&NQ}=hgrad{&NQ-1};

/* If &NQth more than one grade bigger than previous quarter, and */
/* frequency of that value equaly 1, then assume coding error are */
/* reset to match previoius value.                                */
 if hgrad{&NQ}-hgrad{&NQ-1} gt 1 then
  do;
   freq1=0;
   do j=1 to numval;
    if hgrad{&NQ} eq hivalu{j} then freq1=hifreq{j};
   end;
   if freq1 eq 1 then hgrad{&NQ}=hgrad{&NQ-1};
  end;

/* Find decreases or jumps in original HIGRAD values */
 lastb=higrad{1};
 do i=2 to &NQ;
 if higrad{i} ne 0 then
  do;
  if lastb gt higrad{i} then decrsb=1;
  if lastb ne 0 and higrad{i}-lastb gt 1 then jumpb=1;
  lastb=higrad{i};
  end;
 end;
/* Find decreases or jumps in HGRAD values */
 last=hgrad{1};
 do i=2 to &NQ;
 if hgrad{i} ne 0 then
  do;
  if last gt hgrad{i} then hdecrs=1;
  if last ne 0 and hgrad{i}-last gt 1 then hjump=1;
  last=hgrad{i};
  end;
 end;

/* check for changes */
 label diff    ='Num differences between old & new HIGRAD'
       diffnonz='Number of differences, ignoring zeros'
       numzer  ='Number of zeros in old HIGRAD'
       numzrnew='Number of zeros in new HIGRAD'
       badbefor='Had jumps or decreases in old HIGRAD'
       badafter='Has jumps or decreases in new HIGRAD'
       fixed   ='Was bad before but is OK now'
       broke   ='Was OK before but is bad now';
 diff=0; diffnonz=0; numzer=0; numzrnew=0;
 do i=1 to &NQ;
 if higrad{i} ne hgrad{i} then diff=diff+1;
 if higrad{i} ne hgrad{i} and higrad{i} ne 0
     then diffnonz=diffnonz+1;
 if higrad{i} eq 0 then numzer=numzer+1;
 if hgrad{i} eq 0 then numzrnew=numzrnew+1;
 end;
/* Write to LOG file any record for which HIGRAD was all zeros */
/* and the new HGRAD is NOT all zeros (or visa versa).         */
 if (numzer eq &NQ and numzrnew ne &NQ) or
    (numzer ne &NQ and numzrnew eq &NQ) then
  put sunique numzer higrad1-higrad&NQ numzrnew hgrad1-hgrad&NQ
     hygrad1-hygrad&NQ;
/* Flag records with decreases or jumps before any changes. */
 if decrsb eq 1 or jumpb eq 1 then badbefor=1;
/* Flag records with decreases or jumps AFTER the changes. */
 if hdecrs eq 1 or hjump eq 1 then badafter=1;
/* Flag records that got better or worse. */
 if badbefor eq 1 and badafter eq . then fixed=1;
 if badbefor eq . and badafter eq 1 then broke=1;
title "Look at all the people in the &SIPPYEAR SIPP data";
proc freq; tables diff diffnonz numzer numzrnew badbefor badafter
   fixed broke;
run;

title 'New data with revised "Highest Grade Completed" values';
data test2;
 set test;
/* Create a series of %NM dates for the data, based on ROT */
array xyear{&NM} year1-year&NM;
array xmonth{&NM} month1-month&NM;
array xdate{&NM} date1-date&NM;

 if ROT eq 1 then do;year1=&SIPPYEAR;month1=01;end;
  else if ROT eq 2 then do;year1=&SIPPYEAR-1;month1=10;end;
  else if ROT eq 3 then do;year1=&SIPPYEAR-1;month1=11;end;
  else if ROT eq 4 then do;year1=&SIPPYEAR-1;month1=12;end;
 date1=(year1*100) + month1;

 do i=2 to &NM;
 if xmonth{i-1} lt 12 then
  do; xmonth{i}=xmonth{i-1}+1; xyear{i}=xyear{i-1}; end;
 else do; xmonth{i}=1; xyear{i}=xyear{i-1}+1; end;
 xdate{i}=(xyear{i}*100) + xmonth{i};
 end;

 drop year1-year&NM month1-month&NM i;

/* Use macro to expand sequences of %NQ to sequences of &NM. */
%convQtoM(hgrad);
%convQtoM(higrad);
%convQtoM(xedlvl);

 array hg{&NM} hgrad1-hgrad&NM;
 array oldhg{&NM} higrad1-higrad&NM;
 array xinschl{&NM} inschl1-inschl&NM;
/* XEDLVLs are new EDLEVLs, "better" than original */
 array xedlvl{&NM} xedlvl1-xedlvl&NM;

/* Convert data FROM one observation with &NM months  */
/*              TO &NM observations.                  */
 do i=1 to &NM;
  keep sunique date hgrad oldhgrad inschl edlvl ;
  length hgrad inschl edlvl 3;
  date=xdate{i};
  hgrad=hg{i};
  oldhgrad=oldhg{i};
  inschl=xinschl{i};
  if xinschl{i} eq 0 then xedlvl{i}=0;
  edlvl=xedlvl{i};
  output;
 end;

/* Save dataset with SUNIQUE and &NM months of INSCHL values */
/* for  all people in the SIPP panel.                        */
/* data xxx; */
data yyy.schl&SIPPYEAR; 
 set test2;
run;

title 'New values of HIGRAD and related education info';
proc contents;
/* Define a format to show what the EDLVL values mean. */
proc format;
 value schlfmt
    0='No info on enrollment'
    1='Elementary grades 1-8'
    2='High school grades 9-12'
    3='College year 1'
    4='College year 2'
    5='College year 3'
    6='College year 4'
    7='College year 5'
    8='College year 6'
    9='Vocational school'
   10='Technical school'
   11='Business school';
data tmp;
 set yyy.schl&SIPPYEAR;
 format edlvl schlfmt.; 
proc freq;  tables DATE HGRAD OLDHGRAD INSCHL;
proc sort; by inschl edlvl;
proc freq; tables edlvl; by inschl;
run;

/* When merging the new education data with old data,  */
/* it is a good idea to compare the old and new values */
/* of the unedited version of HIGRAD to be sure things */
/* match up correctly.                                 */
/* Following is an example of such a merge.            */
/* (HIGRAD is the variable from the old SIPP file and  */
/* OLDHGRAD is the unedited variable from the new file.*/
/* The match is only done for data that occurs in both */
/* files - that is, in oldstuff and in test2.)         */
/* After the check, the test variables are dropped and */
/* names are changed so HIGRAD is the edited version.  */
/*
data new;
 merge yyy.sipp@SIPPYEAR(in=oldstuff) test2(in=test2); by sunique date;
 if oldstuff;
 matchok=0;
 if test2 and (higrad eq oldhgrad) then matchok=1;
title 'Check if we have correct data - MATCHOK should all be 1 (or missing)';
proc freq; tables matchok;
run; 
data yyy.spp&SIPPYEAR;
 set new(rename=(higrad=tmp hgrad=higrad));
 drop matchok oldhgrad tmp;

endsas;
*/
