options linesize=80 nocenter pagesize=66;
*program immig96.sas: obtains immigrant	status from 1996 topical module 2;
*Date: June 2006;

libname immig '';
filename in1 'c:\SIPP_data\sipp96t2.dat';

data immig.immig96;
infile in1 lrecl=908 missover;

input
@6     PPID      12. /* SSUID    */ 
@25    STATE      2. /* TFIPSST  */
@27    HHADDI2    3. /* SHHADID  */
/* Ignore "interview" variables - EPPMIS4 =1 in all TM records */
/* @55    PPMIS   1.    EPPMIS4  */
/* @45    PPENTRY 3.    EENTAID - Not used in 1996 SIPP */
@48    PPPNUM     4. /* EPPPNUM  */
@70    RRP        2. /* ERRP     */
/* NOTE: In the 1996 data, the list of ethnic origins is */
/* completely different than in past years.              */
@58    ETHNICTY   2. /* EORIGIN  */ 
/* NOTE: Previous SIPP years used a different coding scheme to  */
/* identify location of birth (state not FIPS nor Census Code;  */
/* foreign countries limited to only a few, with max code=99).  */
@853   EBRSTATE   3. /* MG: In what state/country was ... born? */
/*     In what state/country was .... born?                     */
/*V         -1 .Not in universe                                 */
/*V       1:56 .FIPS state code                                 */
/*V     60:555 .Foreign country                                 */
@857   RCITIZNT   2. /* MG: Is .... a U.S. citizen? */
/*     Is .... a U.S. citizen?                      */
/*V         -1 .Not in universe                     */
/*V          1 .Native                              */
/*V          2 .Naturalized citizen                 */
/*V          3 .Not a naturalized citizen           */
/* Following question was not asked in previous SIPP years:   */
@860   RIMSTAT    2. /* MG: What was .... immigration status? */
/*     What was ... immigration status?                       */
/*V         -1 .Not in universe                               */
/*V          1 .Permanent resident                            */
/*V          2 .Other                                         */
@900   RMOVEUS    4. /* MG: Year moved to the United States */
/*     When did ... move to the United States?              */
/*     (Values indicate ranges of years, not actual year.)  */ 

;

*rename/recode immigrant variables;
/* Country of birth */
/* Remember: code values are different in 1996 than previous years! */
 country=EBRSTATE;
 if country=-1 then country=.;

/* Is the person an immigrant? (born in a foreign country and */
/* not born abroad of American parents)                       */
 if EBRSTATE eq -1 then immig=.;
 if EBRSTATE ge 1 and EBRSTATE le 56 then immig=0;
 if EBRSTATE gt 56 then 
   do;
   if RCITIZNT eq 1 then immig=0; /* foreign born but a native citizen */
   if RCITIZNT ne 1 then immig=1;
   end;

/* Is the person not an American citizen? */
 noncit=immig;
 if RCITIZNT eq 2 then noncit=0; /* Naturalized citizen */

*rmoveus=tm8736;

*create ids that are same as for core data;
 syear='96';
 id1='000000000000';
 id1=ppid;
 id3='0000';
 id3=pppnum;
 sunique=syear||id1||id3;

 keep sunique ppid pppnum state hhaddi2 rcitiznt rimstat 
  ethnicty country immig noncit;
run;

proc means;

proc freq;
tables country immig noncit;
tables immig*noncit;



