*kdisab86.sas: Kid disability information for 1986 from topical module
 wave 3, program written by Eileen;
*Date: 07/14/03;

/* Modified March 2004 :                     */
/* - fix incorrect PPENTRY for disabled kids */
/* - add data on kids who are NOT disabled   */ 

options linesize=80 nocenter pagesize=66;

/* libname disab '~ldshore/disk2/disab'; */

/* This program allows for up to 6 different kids per record. */
/* For each of the 6 possible kids, it saves the name of the  */
/* disability variables (up to 3) that specified that kid.    */
/* It uses two-dimension arrays to build a table like this:   */
/*    kidnum{6}      varnm{6,3}                               */
/*    ---------   ----------------                            */
/*    KIDPNUM1    V1N1  V2N1  V3N1                            */
/*    KIDPNUM2    V1N2  V2N2  V3N2                            */
/*    KIDPNUM3    V1N3  V2N3  V3N3                            */
/*    KIDPNUM4    V1N4  V2N4  V3N4                            */
/*    KIDPNUM5    V1N5  V2N5  V3N5                            */
/*    KIDPNUM6    V1N6  V2N6  V3N6                            */
/* After creating the table for a record, it breaks the data  */
/* into separate records for each kid in the table, keeping   */
/* only those that have a non-missing KIDNUM.                 */

data tm3;
 filename in1 PIPE 'gunzip -c ~ldshore/disk2/sipp/1986/da9319tm.recwave3.gz';
 infile in1 lrecl=5949 recfm=f missover;
 input
  @6   PPID      9.
  @15  ROT       1.
  @43	addid1 2. 
  @299	addid2 2.  
  @555	addid3 2. 
  @811	addid4 2. 
  @1077	addid5 2. 
  @2007 (ppmis1-ppmis5) (1.)
  @2012  PPENTRY        2.
  @2014  PPPNUM         3.
  @2085 (AGE1-age5)  (2.)    
  @2133 (PNPT1-PNPT5) (3.)
  @5916 TM8602          1.
  @5917 TM8604          3.
  @5920 TM8606          3.
  @5923 TM8608          3.
  @5926 TM8610          1.
  @5927 TM8612          3.
  @5930 TM8614          3.
  @5933 TM8616          3.
 ;
run;

data dkids;
/* Change names of PPPNUM,PPENTRY,ADDID in the TM3 data:  */
/* XPPPNUM,XPPENTRY,XADDID are now the Parent's values.   */
 set tm3(rename=(pppnum=xpppnum ppentry=xppentry addid1=xaddid1
       addid2=xaddid2 addid3=xaddid3 addid4=xaddid4 addid5=xaddid5)); 

 array yesno{2} tm8602 tm8610;
 array kid{2,3} tm8604 tm8606 tm8608
                tm8612 tm8614 tm8616;

 array kidnum{6} kidpnum1-kidpnum6;
 array varnm{6,2} v1n1-v1n6 v2n1-v2n6;

/* Initialize the new variables. */
 do i=1 to 6;
  kidnum{i}=.;
  do j=1 to 2;
  varnm{i,j}=.;
  end;
 end;

/* Check each of the 2 "yes/no" variables. */
 do i=1 to 2;
/* Define (as a numeric value) the variable which is being checked. */
 which=input(scan('8602 8610',i),4.);
/* When there is a "yes", check each possible kid and save info. */
  if yesno{i} eq 1 then
/* Check Each of the Three Children. */
   do k=1 to 3; 
    where=.;
    do j=1 to 6 while (where eq .);
     if kidnum{j} eq . or kidnum{j} eq kid{i,k} then where=j;
    end; 
/* If there is a non-zero kid PPPNUM, save the info. */
    if kid{i,k} ne 0 then 
    do;
/* Store the kid's PPPNUM. */
    kidnum{where}=kid{i,k};
/* Store which disability it is. */
    do d=1 to 2;
      if varnm{where,d} eq . then 
        do;
        varnm{where,d}=which;
        go to gotit;
        end;
    end;
    gotit:;
    end; /* End of DO for a non-zero kid PPPNUM. */
   end; /* End of loop for the Three Children. */
 end; /* End of loop checking "yes/no". */

/* Break the record into separate pieces for each kid. */
 do i=1 to 6;
/* Only do it if the kidnum isn't missing. */
 if kidnum{i} ne . then
 do;

 kdisab=1;

 varname1=varnm{i,1};
 varname2=varnm{i,2};

 pppnum=kidnum{i}; /* Set kid's PPPNUM */

 keep kdisab varname1-varname2 xppentry xpppnum xaddid1-xaddid5
      ppid pppnum age1-age4;

/* Throw data away if kid's PPPNUM matches parent XPPPNUM */
 if pppnum eq xpppnum then  
   do;
   put '.';
   put ' *********************************************************';
   put ' ERROR: Kid PPPNUM matches Parent PPPNUM '
     ppid xppentry pppnum kidnum(i) varname1 varname2 ;
   put ' THIS RECORD IS BEING DROPPED ';
   put ' *********************************************************';
   put '.';
   end;
 else
/* Keep all other kids records */ 
   output;

 end; /* End of DO for kidnum ne . */
 end; /* End of loop for the 6 possible kids. */
run;

/* Merge the Disabled Kid data back onto the TM3 data, */
/* by PPID and PPPNUM.  This is necessary to get the   */
/* correct PPENTRY of the Disabled Kid because kid's   */
/* PPENTRY not recorded in the Parent's record, which  */
/* is the source of the kid's disability information.  */
proc sort data=tm3; by ppid pppnum;
proc sort data=dkids; by ppid pppnum;
data dkids;
 merge dkids(in=k) tm3; by ppid pppnum;
 if k;
/* If potential parent lives in a different HHADDI, drop them */
/* Note that for 1986, must check 5 months of wave because    */
/* there is no single HHADDI value that seems valid.          */
 if addid1 ne xaddid1 and addid2 ne xaddid2 and
    addid3 ne xaddid3 and addid4 ne xaddid4 and
    addid5 ne xaddid5  then
  do;
  put 'ADDID does not match potential parent record ';
  put 'Parent cannot live at different address - deleting this record';
  put '  ' ppid ppentry pppnum addid1-addid5 xaddid1-xaddid5
           xppentry xpppnum;
  delete;
  end;
/* Create an ID for this kid. */
 syear='86';
 id1='000000000';
 id1=ppid;
 id2='00';
 id2=ppentry;
 id3='000';
 id3=pppnum;
 sunique=syear||id1||id2||id3;
 drop syear id1 id2 id3;
run;
proc sort; by sunique;

data chk;
 set dkids;
 if ppentry ne xppentry;
title 'Kids with different PPENTRY values than the parent who listed them';
title2 '(Note: XPPENTRY & XPPPNUM are for parent who listed the kid.)';
proc print; var sunique age1-age4 kdisab varname1 varname2  
  ppmis1-ppmis5 pnpt1-pnpt5 xppentry xpppnum;
run;

/* check ages of kids with disabilities - both categories in */
/* the 1986 SIPP wave3 data must be less than 18 years old.  */
title 'Ages of disabled kids';
proc freq data=dkids; tables age1-age4;
run;

/* Keep only the necessary info for the disabled kids */
data dkids;
 set dkids;
 keep sunique kdisab varname1-varname2;
run;

/* Get all the families in the main SIPP data */
libname x '';
data allkids;
 set x.fam86;
 keep sunique ppid hhaddi famid famstr relat mnum date 
   pppnum ppmis ubrthmn ubrthyr parid parguard;
run;
proc sort; by ppid mnum hhaddi famid relat;
run;
/* Process BY FAMILY to find both parents in 2-parent family */
data allkids;
 set allkids; by ppid mnum hhaddi famid;
/* For 2-parent families, get IDs of both parents             */
/* (REF is ReferencePerson, SPO is Spouse of ReferencePerson) */
 length ref spo $ 18;
 retain ref spo;
 if first.ppid and first.mnum and first.hhaddi and first.famid then
  do; ref=''; spo=''; end;
 if famstr eq 2 then
  do;
   if relat eq 1 then ref=sunique;
   if relat eq 2 then spo=sunique;
  end;
/* Only use children with PPPNUM less than 400 (400 or higher */
/* means they entered the sample AFTER wave 3, when disability*/
/* information was gathered from the parents)                 */
 if pppnum lt 400;
/* NOTE: For the 1986 data, maximum age for disability question */
/* is 18, not 23 as it was in other years. *****                */
/* Find all children LE 18 years old at start of wave 3 (MNUM=9) */
/* - use birth month&year rather than age since person might not */
/* be in the data during months 9 through 12.                    */
 attrib mdate brthdate format=mmddyy8.;
 xyr=int(date/100);    /* year of data record */
 xmn=date-(xyr*100);   /* month of data record */
 mdate=mdy(xmn,1,xyr); /* SAS "date" variable of data record */
 brthdate=mdy(ubrthmn,1,ubrthyr); /* "date" variable" of birthdate */
/* Compute age at start of month 9 (i.e., first month of wave 3)*/
/* based on offset from current month (i.e., "9-mnum").         */
 m9age=int((intnx('MONTH',mdate,(9-mnum))-brthdate)/365);
/* Compute age at start of month 13 (interview month for wave 3) */
/* based on offset from current month (i.e., "13-mnum"). Discard */
/* anyone who wasn't born by month 13, since can't be in wave3.  */
 m13age=(intnx('MONTH',mdate,(13-mnum))-brthdate)/365;
/* For all kids 18 years or less in month 9, keep their id,     */
/* parent id, and guardian flag.  If their FAMSTR is a 2-parent */
/* family, and they are RELAT=3 (child of ReferencePerson) use  */
/* the id of BOTH parents and "output" two records)             */
 keep sunique parid parguard; 
 if m9age le 18 and m13age ge 0 and ppmis eq 1 then
  do;
/* For all kids not ChildOfReferencePerson in 2-parent family,  */
/* output one record with the child's PARID (if one exists).    */
    if not (famstr eq 2 and relat eq 3) and parid ne '' then output;
    else if famstr eq 2 and relat eq 3 then
/* For ChildOfReferencePerson in 2-parent family, check that  */
/* their PARID is one of those 2, and output both parents.    */
     do;
      if parid ne ref and parid ne spo and parid ne '' then
        put "PROBLEM: PARID ne ReferencePerson or Spouse" sunique
          mnum parid ref spo famstr m9age;
      parid=ref;
      output;
      parid=spo;
      output;
    end;
  end;
run;
proc sort nodupkey; by sunique parid;
run;

/* Find all the people who have at least one PPMIS=1 value */
/* in the 5 values in TopicalModule3 - these could have    */
/* supplied valid answers to the disability questions.     */
data adults;
 set tm3;
 if ppmis1 eq 1 or ppmis2 eq 1 or ppmis3 eq 1 or ppmis4 eq 1 or ppmis5 eq 1;
/* Create an ID for this person */
 syear='86';
 id1='000000000';
 id1=ppid;
 id2='00';
 id2=ppentry;
 id3='000';
 id3=pppnum;
 parid=syear||id1||id2||id3;
 keep parid;
run;
proc sort nodupkey; by parid;
run;

/* Map these people onto the list of kid's parents or guardians */
proc sort data=allkids; by parid;
data allkids;
 merge allkids(in=k) adults(in=a); by parid;
/* If a kid has a parent or guardian in the list of people   */
/* in TopicalModule3 with any instances of PPMIS1-PPMIS5 =1, */
/* then that kid COULD have been identified as disabled.     */
 if k and a;
/* Keep only the list of kids */
 keep sunique;
run;
proc sort nodupkey; by sunique;
run;

/* Merge this list of kids with the list of Disabled Kids */
data x.kdisab86;
 merge allkids dkids(in=in_dkid); by sunique;
/* If they have not been identified as Disabled, they are NOT */
/* disabled but could have been identified if they were.      */
 if not in_dkid then kdisab=0;
/* Set length to minimize dataset storage size */
 length kdisab 3 varname1 varname2 4;
run;

title 'Disability & Non-Disability information for all kids';
proc freq; tables kdisab;
run;

/* Check .log to be sure no duplicates were present */
proc sort nodupkey; by sunique;
run;
proc contents;
proc means;
run;

options obs=200;
title 'First 200 records of Disability Data';
proc print;
endsas;
