*kdisab90.sas: Kid disability information for 1990 from topical module
 wave 3, program written by Eileen;
*Date: 07/14/03;

/* Modified March 2004 :                     */
/* - fix incorrect PPENTRY for disabled kids */
/* - add data on kids who are NOT disabled   */ 

options linesize=80 nocenter pagesize=66;

/* libname disab '~ldshore/disk2/disab'; */

/* This program allows for up to 6 different kids per record. */
/* For each of the 6 possible kids, it saves the name of the  */
/* disability variables (up to 3) that specified that kid.    */
/* It uses two-dimension arrays to build a table like this:   */
/*    kidnum{6}      varnm{6,3}                               */
/*    ---------   ----------------                            */
/*    KIDPNUM1    V1N1  V2N1  V3N1                            */
/*    KIDPNUM2    V1N2  V2N2  V3N2                            */
/*    KIDPNUM3    V1N3  V2N3  V3N3                            */
/*    KIDPNUM4    V1N4  V2N4  V3N4                            */
/*    KIDPNUM5    V1N5  V2N5  V3N5                            */
/*    KIDPNUM6    V1N6  V2N6  V3N6                            */
/* After creating the table for a record, it breaks the data  */
/* into separate records for each kid in the table, keeping   */
/* only those that have a non-missing KIDNUM.                 */

data tm3;
 filename in1 PIPE 'gunzip -c ~ldshore/disk2/sipp/1990/da9722tm.wave3mic.gz';
 infile in1 lrecl=1052 recfm=f missover;
 input
  @6   PPID      9.
  @15  ROT       1.
  @20  ADDID     2.
  @25  PPENTRY        2.
  @27  PPPNUM         3.
  @43  AGE            3.
  @52  PNPT           3.
  @824	TM8944		1.
  @825	TM8946		3.
  @828	TM8948		3.
  @831	TM8950		3.
  @834	TM8952		1.
  @835	TM8954		3.
  @838	TM8956		3.
  @841	TM8958		3.
  @845	TM8962		1.
  @846	TM8964		3.
  @849	TM8966		3.
  @852	TM8968		3.
  @876	TM8988		1.
  @877	TM8990		3.
  @880	TM8992		3.
  @883	TM8994		3.
 ;
run;

data dkids;
/* Change names of PPPNUM,PPENTRY,ADDID in the TM3 data:  */
/* XPPPNUM,XPPENTRY,ADDID are now the Parent's values.    */
 set tm3(rename=(pppnum=xpppnum ppentry=xppentry addid=xaddid)); 
 array yesno{4} tm8944 tm8952 tm8962 tm8988;
 array kid{4,3} tm8946 tm8948 tm8950
                tm8954 tm8956 tm8958 
                tm8964 tm8966 tm8968
                tm8990 tm8992 tm8994;

 array kidnum{6} kidpnum1-kidpnum6;
 array varnm{6,3} v1n1-v1n6 v2n1-v2n6 v3n1-v3n6;

/* Initialize the new variables. */
 do i=1 to 6;
  kidnum{i}=.;
  do j=1 to 3;
  varnm{i,j}=.;
  end;
 end;

/* Check each of the 4 "yes/no" variables. */
 do i=1 to 4;
/* Define (as a numeric value) the variable which is being checked. */
 which=input(scan('8944 8952 8962 8988',i),4.);
/* When there is a "yes", check each possible kid and save info. */
  if yesno{i} eq 1 then
/* Check Each of the Three Children. */
   do k=1 to 3; 
    where=.;
    do j=1 to 6 while (where eq .);
     if kidnum{j} eq . or kidnum{j} eq kid{i,k} then where=j;
    end; 
/* If there is a non-zero kid PPPNUM, save the info. */
    if kid{i,k} ne 0 then 
    do;
/* Store the kid's PPPNUM. */
    kidnum{where}=kid{i,k};
/* Store which disability it is. */
    do d=1 to 3;
      if varnm{where,d} eq . then 
        do;
        varnm{where,d}=which;
        go to gotit;
        end;
    end;
    gotit:;
    end; /* End of DO for a non-zero kid PPPNUM. */
   end; /* End of loop for the Three Children. */
 end; /* End of loop checking "yes/no". */

/* Break the record into separate pieces for each kid. */
 do i=1 to 6;
/* Only do it if the kidnum isn't missing. */
 if kidnum{i} ne . then
 do;

 kdisab=1;

 varname1=varnm{i,1};
 varname2=varnm{i,2};
 varname3=varnm{i,3};

 pppnum=kidnum{i}; /* Set kid's PPPNUM */

 keep kdisab varname1-varname3 xppentry xpppnum xaddid ppid pppnum;

/* Throw data away if kid's PPPNUM matches parent XPPPNUM */
 if pppnum eq xpppnum then  
   do;
   put '.';
   put ' *********************************************************';
   put ' ERROR: Kid PPPNUM matches Parent PPPNUM '
     ppid xppentry pppnum kidnum(i) varname1 varname2 varname3;
   put ' THIS RECORD IS BEING DROPPED ';
   put ' *********************************************************';
   put '.';
   end;
 else
/* Keep all other kids records */ 
   output;

 end; /* End of DO for kidnum ne . */
 end; /* End of loop for the 6 possible kids. */
run;

/* Merge the Disabled Kid data back onto the TM3 data, */
/* by PPID and PPPNUM.  This is necessary to get the   */
/* correct PPENTRY of the Disabled Kid because kid's   */
/* PPENTRY not recorded in the Parent's record, which  */
/* is the source of the kid's disability information.  */
proc sort data=tm3; by ppid pppnum;
proc sort data=dkids; by ppid pppnum;
data dkids;
 merge dkids(in=k) tm3; by ppid pppnum;
 if k;
run;

/* Check to be sure there are no duplicate kid IDs */
proc sort nodupkey data=dkids out=chk; by ppid pppnum;
run;

/* Special case in the 1990 SIPP - drop child who cannot */
/* be positively identified in data because of duplicate */
/* PPPNUM values in the PPID.                            */
data dkids;
 set dkids;
 if ppid eq 192651253 and pppnum eq 302 then delete;
run;

data dkids;
 set dkids;
/* If potential parent lives in a different HHADDI, drop them */
 if addid ne xaddid then
  do;
  put 'ADDID does not match potential parent record ';
  put 'Parent cannot live at different address - delete this record';
  put '  ' ppid ppentry pppnum addid xaddid xppentry xpppnum;
  delete;
  end;
/* Create an ID for this kid. */
 syear='90';
 id1='000000000';
 id1=ppid;
 id2='00';
 id2=ppentry;
 id3='000';
 id3=pppnum;
 sunique=syear||id1||id2||id3;
 drop syear id1 id2 id3;
run;
proc sort; by sunique;

data chk;
 set dkids;
 if ppentry ne xppentry;
title 'Kids with different PPENTRY values than the parent who listed them';
title2 '(Note: XPPENTRY & XPPPNUM are for parent who listed the kid.)';
proc print; var sunique age kdisab varname1 varname2 varname3 
   pnpt xppentry xpppnum;
run;

/* Keep only the necessary info for the disabled kids */
data dkids;
 set dkids;
 keep sunique kdisab varname1-varname3;
run;

/* Get all the families in the main SIPP data */
libname x '';
data allkids;
 set x.fam90;
 keep sunique ppid hhaddi famid famstr relat mnum date 
   pppnum ppmis ubrthmn ubrthyr parid parguard;
run;
proc sort; by ppid mnum hhaddi famid relat;
run;
/* Process BY FAMILY to find both parents in 2-parent family */
data allkids;
 set allkids; by ppid mnum hhaddi famid;
/* For 2-parent families, get IDs of both parents             */
/* (REF is ReferencePerson, SPO is Spouse of ReferencePerson) */
 length ref spo $ 16;
 retain ref spo;
 if first.ppid and first.mnum and first.hhaddi and first.famid then
  do; ref=''; spo=''; end;
 if famstr eq 2 then
  do;
   if relat eq 1 then ref=sunique;
   if relat eq 2 then spo=sunique;
  end;
/* Only use children with PPPNUM less than 400 (400 or higher */
/* means they entered the sample AFTER wave 3, when disability*/
/* information was gathered from the parents)                 */
 if pppnum lt 400;
/* Find all children LE 23 years old at start of wave 3 (MNUM=9) */
/* - use birth month&year rather than age since person might not */
/* be in the data during months 9 through 12.                    */
 attrib mdate brthdate format=mmddyy8.;
 xyr=int(date/100);    /* year of data record */
 xmn=date-(xyr*100);   /* month of data record */
 mdate=mdy(xmn,1,xyr); /* SAS "date" variable of data record */
 brthdate=mdy(ubrthmn,1,ubrthyr); /* "date" variable" of birthdate */
/* Compute age at start of month 9 (i.e., first month of wave 3) */
/* based on offset from current month (i.e., "9-mnum").          */
 m9age=int((intnx('MONTH',mdate,(9-mnum))-brthdate)/365);
/* Compute age at start of month 13 (interview month for wave 3) */
/* based on offset from current month (i.e., "13-mnum"). Discard */
/* anyone who wasn't born by month 13, since can't be in wave3.  */
 m13age=(intnx('MONTH',mdate,(13-mnum))-brthdate)/365;
/* For all kids 23 years or less in month 9, keep their id,     */
/* parent id, and guardian flag.  If their FAMSTR is a 2-parent */
/* family, and they are RELAT=3 (child of ReferencePerson) use  */
/* the id of BOTH parents and "output" two records)             */
 keep sunique parid parguard; 
 if m9age le 23 and m13age ge 0 and ppmis eq 1 then
  do;
/* For all kids not ChildOfReferencePerson in 2-parent family,  */
/* output one record with the child's PARID (if one exists).    */
    if not (famstr eq 2 and relat eq 3) and parid ne '' then output;
    else if famstr eq 2 and relat eq 3 then
/* For ChildOfReferencePerson in 2-parent family, check that  */
/* their PARID is one of those 2, and output both parents.    */
     do;
      if parid ne ref and parid ne spo and parid ne '' then
        put "PROBLEM: PARID ne ReferencePerson or Spouse" sunique
          mnum parid ref spo famstr m9age;
      parid=ref;
      output;
      parid=spo;
      output;
    end;
  end;
run;
proc sort nodupkey; by sunique parid;
run;

/* Find all the people who have at least one PPMIS=1 value */
/* in the 5 values in TopicalModule3 - these could have    */
/* supplied valid answers to the disability questions.     */
/* IN 1990 SIPP TOPICAL MODULE 3 THERE ARE NO PPMIS VALUES,*/
/* SO USE ALL THE PEOPLE IN THE FILE !!                    */
data adults;
 set tm3;
/* if ppmis1 eq 1 or ppmis2 eq 1 or ppmis3 eq 1 or ppmis4 eq 1 or
    ppmis5 eq 1; */   /* DO NOT DO THIS FOR 1990 SIPP !!! */
/* Create an ID for this person */
 syear='90';
 id1='000000000';
 id1=ppid;
 id2='00';
 id2=ppentry;
 id3='000';
 id3=pppnum;
 parid=syear||id1||id2||id3;
 keep parid;
run;
proc sort nodupkey; by parid;
run;

/* For the 1990 data, map the people in the TopicalModule    */
/* with the people from the family dataset and keep only the */
/* one with PPMIS=1 for at least one month from 9 through 13.*/
data wave3;
 set x.fam90;
 if mnum in(9,10,11,12,13) and ppmis eq 1;
 keep sunique;
 rename sunique=parid;
run;
proc sort nodupkey; by parid;
run;
data adults;
 merge wave3(in=w3) adults(in=a); by parid;
 if w3 and a;
run;

/* Map these people onto the list of kid's parents or guardians */
proc sort data=allkids; by parid;
data allkids;
 merge allkids(in=k) adults(in=a); by parid;
/* If a kid has a parent or guardian in the list of people   */
/* in TopicalModule3 with any instances of PPMIS1-PPMIS5 =1, */
/* then that kid COULD have been identified as disabled.     */
 if k and a;
/* Keep only the list of kids */
 keep sunique;
run;
proc sort nodupkey; by sunique;
run;

/* Merge this list of kids with the list of Disabled Kids */
data x.kdisab90;
 merge allkids dkids(in=in_dkid); by sunique;
/* If they have not been identified as Disabled, they are NOT */
/* disabled but could have been identified if they were.      */
 if not in_dkid then kdisab=0;
/* Set length to minimize dataset storage size */
 length kdisab 3 varname1 varname2 varname3 4;
run;

title 'Disability & Non-Disability information for all kids';
proc freq; tables kdisab;
run;

/* Check .log to be sure no duplicates were present */
proc sort nodupkey; by sunique;
run;
proc contents;
proc means;
run;

options obs=200;
title 'First 200 records of Disability Data';
proc print;
endsas;
