*kdisab92.sas: Kid disability information for 1992 from topical module
 wave 6, program written by Eileen;
*Date: 07/14/03;

/* Modified March 2004 :                     */
/* - fix incorrect PPENTRY for disabled kids */
/* - add data on kids who are NOT disabled   */ 

options linesize=80 nocenter pagesize=66;

/* libname disab '~ldshore/disk2/disab'; */

/* This program allows for up to 6 different kids per record. */
/* For each of the 6 possible kids, it saves the name of the  */
/* disability variables (up to 3) that specified that kid.    */
/* It uses two-dimension arrays to build a table like this:   */
/*    kidnum{6}      varnm{6,3}                               */
/*    ---------   ----------------                            */
/*    KIDPNUM1    V1N1  V2N1  V3N1                            */
/*    KIDPNUM2    V1N2  V2N2  V3N2                            */
/*    KIDPNUM3    V1N3  V2N3  V3N3                            */
/*    KIDPNUM4    V1N4  V2N4  V3N4                            */
/*    KIDPNUM5    V1N5  V2N5  V3N5                            */
/*    KIDPNUM6    V1N6  V2N6  V3N6                            */
/* After creating the table for a record, it breaks the data  */
/* into separate records for each kid in the table, keeping   */
/* only those that have a non-missing KIDNUM.                 */

data tm6;
 filename in1 PIPE 'gunzip -c ~ldshore/disk2/sipp/1992/da6429tm.wave6.gz';
 infile in1 lrecl=1261 recfm=f missover;
 input
  @6   PPID      9.
  @15  ROT       1.
  @20  ADDID     2.
  @25  (PPMIS1-PPMIS5) (1.)
  @30  PPENTRY   2.
  @32  PPPNUM    3.
  @48  AGE       3.
  @57  PNPT      3.
  @1040     TM8944         1.
  @1041     TM8946         3.
  @1044     TM8948         3.
  @1047     TM8950         3.
  @1050     TM8952         1.
  @1051     TM8954         3.
  @1054     TM8956         3.
  @1057     TM8958         3.
  @1061     TM8962         1.
  @1062     TM8964         3.
  @1065     TM8966         3.
  @1068     TM8968         3.
  @1092     TM8988         1.
  @1093     TM8990         3.
  @1096     TM8992         3.
  @1099     TM8994         3.
 ;
run;

data dkids;
/* Change names of PPPNUM,PPENTRY,ADDID in the TM6 data:  */
/* XPPPNUM,XPPENTRY,XADDID are now the Parent's values.   */
 set tm6(rename=(pppnum=xpppnum ppentry=xppentry addid=xaddid)); 
 array yesno{4} tm8944 tm8952 tm8962 tm8988;
 array kid{4,3} tm8946 tm8948 tm8950
                tm8954 tm8956 tm8958 
                tm8964 tm8966 tm8968
                tm8990 tm8992 tm8994;

 array kidnum{6} kidpnum1-kidpnum6;
 array varnm{6,3} v1n1-v1n6 v2n1-v2n6 v3n1-v3n6;

/* Initialize the new variables. */
 do i=1 to 6;
  kidnum{i}=.;
  do j=1 to 3;
  varnm{i,j}=.;
  end;
 end;

/* Check each of the 4 "yes/no" variables. */
 do i=1 to 4;
/* Define (as a numeric value) the variable which is being checked. */
 which=input(scan('8944 8952 8962 8988',i),4.);
/* When there is a "yes", check each possible kid and save info. */
  if yesno{i} eq 1 then
/* Check Each of the Three Children. */
   do k=1 to 3; 
    where=.;
    do j=1 to 6 while (where eq .);
     if kidnum{j} eq . or kidnum{j} eq kid{i,k} then where=j;
    end; 
/* If there is a non-zero kid PPPNUM, save the info. */
    if kid{i,k} ne 0 then 
    do;
/* Store the kid's PPPNUM. */
    kidnum{where}=kid{i,k};
/* Store which disability it is. */
    do d=1 to 3;
      if varnm{where,d} eq . then 
        do;
        varnm{where,d}=which;
        go to gotit;
        end;
    end;
    gotit:;
    end; /* End of DO for a non-zero kid PPPNUM. */
   end; /* End of loop for the Three Children. */
 end; /* End of loop checking "yes/no". */

/* Break the record into separate pieces for each kid. */
 do i=1 to 6;
/* Only do it if the kidnum isn't missing. */
 if kidnum{i} ne . then
 do;

 kdisab=1;

 varname1=varnm{i,1};
 varname2=varnm{i,2};
 varname3=varnm{i,3};

 pppnum=kidnum{i}; /* Set kid's PPPNUM */

 keep kdisab varname1-varname3 xppentry xpppnum xaddid ppid pppnum;

/* Throw data away if kid's PPPNUM matches parent XPPPNUM */
 if pppnum eq xpppnum then  
   do;
   put '.';
   put ' *********************************************************';
   put ' ERROR: Kid PPPNUM matches Parent PPPNUM '
     ppid xppentry pppnum kidnum(i) varname1 varname2 varname3;
   put ' THIS RECORD IS BEING DROPPED ';
   put ' *********************************************************';
   put '.';
   end;
 else
/* Keep all other kids records */ 
   output;

 end; /* End of DO for kidnum ne . */
 end; /* End of loop for the 6 possible kids. */
run;

/* Merge the Disabled Kid data back onto the TM6 data, */
/* by PPID and PPPNUM.  This is necessary to get the   */
/* correct PPENTRY of the Disabled Kid because kid's   */
/* PPENTRY not recorded in the Parent's record, which  */
/* is the source of the kid's disability information.  */
proc sort data=tm6; by ppid pppnum;
proc sort data=dkids; by ppid pppnum;
data dkids;
 merge dkids(in=k) tm6; by ppid pppnum;
 if k;
/* If potential parent lives in a different HHADDI, drop them */
 if addid ne xaddid then
  do;
  put 'ADDID does not match potential parent record ';
  put 'Parent cannot live at different address - delete this record';
  put '  ' ppid ppentry pppnum addid xaddid xppentry xpppnum;
  delete;
  end;
/* Special-handling - kid in data twice: identified as disabled */
/* by both mother and grandmother - drop grandmother record.    */
 if ppid eq 391451098 and ppentry eq 11 and pppnum eq 106
    and xpppnum eq 101 then delete;
/* Create an ID for this kid. */
 syear='92';
 id1='000000000';
 id1=ppid;
 id2='000';
 id2=ppentry;
 id3='0000';
 id3=pppnum;
 sunique=syear||id1||id2||id3;
 drop syear id1 id2 id3;
run;
proc sort; by sunique;

data chk;
 set dkids;
 if ppentry ne xppentry;
title 'Kids with different PPENTRY values than the parent who listed them';
title2 '(Note: XPPENTRY & XPPPNUM are for parent who listed the kid.)';
proc print; var sunique age kdisab varname1 varname2 varname3 
  ppmis1-ppmis5 pnpt xppentry xpppnum;
run;

/* Keep only the necessary info for the disabled kids */
data dkids;
 set dkids;
 keep sunique kdisab varname1-varname3;
run;

/* Get all the families in the main SIPP data */
libname x '';
data allkids;
 set x.fam92;
 keep sunique ppid hhaddi famid famstr relat mnum date 
   pppnum ppmis ubrthmn ubrthyr parid parguard;
run;
proc sort; by ppid mnum hhaddi famid relat;
run;
/* Process BY FAMILY to find both parents in 2-parent family */
data allkids;
 set allkids; by ppid mnum hhaddi famid;
/* For 2-parent families, get IDs of both parents             */
/* (REF is ReferencePerson, SPO is Spouse of ReferencePerson) */
 length ref spo $ 18;
 retain ref spo;
 if first.ppid and first.mnum and first.hhaddi and first.famid then
  do; ref=''; spo=''; end;
 if famstr eq 2 then
  do;
   if relat eq 1 then ref=sunique;
   if relat eq 2 then spo=sunique;
  end;
/* Only use children with PPPNUM less than 700 (700 or higher */
/* means they entered the sample AFTER wave 6, when disability*/
/* information was gathered from the parents)                 */
 if pppnum lt 700;
/* Find all children LE 23 years old at start of wave 6 (MNUM=21)*/
/* - use birth month&year rather than age since person might not */
/* be in the data during months 21 through 24.                    */
 attrib mdate brthdate format=mmddyy8.;
 xyr=int(date/100);    /* year of data record */
 xmn=date-(xyr*100);   /* month of data record */
 mdate=mdy(xmn,1,xyr); /* SAS "date" variable of data record */
 brthdate=mdy(ubrthmn,1,ubrthyr); /* "date" variable" of birthdate */
/* Compute age at start of month 21 (i.e., first month of wave 6)*/
/* based on offset from current month (i.e., "21-mnum").         */
 m21age=int((intnx('MONTH',mdate,(21-mnum))-brthdate)/365);
/* Compute age at start of month 25 (interview month for wave 6) */
/* based on offset from current month (i.e., "25-mnum"). Discard */
/* anyone who wasn't born by month 25, since can't be in wave6.  */
 m25age=(intnx('MONTH',mdate,(25-mnum))-brthdate)/365;
/* For all kids 23 years or less in month 21, keep their id,     */
/* parent id, and guardian flag.  If their FAMSTR is a 2-parent */
/* family, and they are RELAT=3 (child of ReferencePerson) use  */
/* the id of BOTH parents and "output" two records)             */
 keep sunique parid parguard; 
 if m21age le 23 and m25age ge 0 and ppmis eq 1 then
  do;
/* For all kids not ChildOfReferencePerson in 2-parent family,  */
/* output one record with the child's PARID (if one exists).    */
    if not (famstr eq 2 and relat eq 3) and parid ne '' then output;
    else if famstr eq 2 and relat eq 3 then
/* For ChildOfReferencePerson in 2-parent family, check that  */
/* their PARID is one of those 2, and output both parents.    */
     do;
      if parid ne ref and parid ne spo and parid ne '' then
        put "PROBLEM: PARID ne ReferencePerson or Spouse" sunique
          mnum parid ref spo famstr m21age;
      parid=ref;
      output;
      parid=spo;
      output;
    end;
  end;
run;
proc sort nodupkey; by sunique parid;
run;

/* Find all the people who have at least one PPMIS=1 value */
/* in the 5 values in TopicalModule6 - these could have    */
/* supplied valid answers to the disability questions.     */
data adults;
 set tm6;
 if ppmis1 eq 1 or ppmis2 eq 1 or ppmis3 eq 1 or ppmis4 eq 1 or
    ppmis5 eq 1;
/* Create an ID for this person */
 syear='92';
 id1='000000000';
 id1=ppid;
 id2='000';
 id2=ppentry;
 id3='0000';
 id3=pppnum;
 parid=syear||id1||id2||id3;
 keep parid;
run;
proc sort nodupkey; by parid;
run;

/* Map these people onto the list of kid's parents or guardians */
proc sort data=allkids; by parid;
data allkids;
 merge allkids(in=k) adults(in=a); by parid;
/* If a kid has a parent or guardian in the list of people   */
/* in TopicalModule6 with any instances of PPMIS1-PPMIS5 =1, */
/* then that kid COULD have been identified as disabled.     */
 if k and a;
/* Keep only the list of kids */
 keep sunique;
run;
proc sort nodupkey; by sunique;
run;

/* Merge this list of kids with the list of Disabled Kids */
data x.kdisab92;
 merge allkids dkids(in=in_dkid); by sunique;
/* If they have not been identified as Disabled, they are NOT */
/* disabled but could have been identified if they were.      */
 if not in_dkid then kdisab=0;
/* Set length to minimize dataset storage size */
 length kdisab 3 varname1 varname2 varname3 4;
run;

title 'Disability & Non-Disability information for all kids';
proc freq; tables kdisab;
run;

/* Check .log to be sure no duplicates were present */
proc sort nodupkey; by sunique;
run;
proc contents;
proc means;
run;

options obs=200;
title 'First 200 records of Disability Data';
proc print;
endsas;
