options linesize=80 nocenter pagesize=66;
*kdisab96.sas: Kid disability information for 1996 from topical module
 wave 5, program written by Eileen;
*Date: 05/25/06;

/* All variables related to disability are read in, but they are   */
/* not all used in our definition of child disability.  Only four  */
/* questions were asked of parents in the 1993 SIPP TopicalModule. */

/* There was a question in 1993 for kids younger than 6, asking if */
/* they "received therapy or diagnostic services designed to meet  */
/* their developmemtal needs".  There is no such question in 1996  */
/* but BOTH years ask if kids less than 6 have a physical or mental*/
/* condition or developmental delay that limits ordinary activities*/
/* done by most children their age (we use this in 1996 and in all */
/* the older SIPP years) - that should capture the same condition  */
/* as the missing question, so we will probably not miss any kids. */

/* The 1993 question on ability to walk/run was asked for kids age */
/* 3 through 14; in 1996, ERUNPLAY applies to ages 3 through 5 and */
/* ESPORTS applies to ages 6 through 14, so both are used.         */

libname disab '';

data disab.kdisab96;
 filename in1 'c:\SIPP_data\sipp96t5.dat';
 infile in1 lrecl=2044 missover;
 input
  @6   PPID     12. /* SSUID    */
  @48  PPPNUM    4. /* EPPNUM   */
/* Ignore "interview" variables - PPMIS4 =1 in all TM records */
/*  @53  PPINTVW   2.  1,2=interview; 3,4=non-interview; 5=child < 15 */
/*  @55  PPMIS4    1.  1=interview; 2=non-interview */
  @72  AGE       2. /* EAGE     */
  @79  PNMOM     4. /* EPNMOM   */
  @83  PNDAD     4. /* EPNDAD   */
  @87  PNGD      4. /* EPNGUARD */
  @1728 EPCDUNV 2. /* Universe indicator: All children  */
/*                     1=in-universe; -1=not-in-universe */
/* For the following, responses are: */
/*      -1 .Not in universe          */
/*       1 .Yes                      */
/*       2 .No                       */
  @1730 EDDELAY  2. /* CDQ: Serious physical/mental condition   */
/*     CDQ1A Does the child (age less than 6) have a serious    */
/*     physical or mental condition or a developmental delay    */
/*     that limits ordinary activities?                         */
  @1733 EARMLEG  2. /* CDQ: Condition limiting the use of arms/legs */
/*     CDQ1B Does the child (age less than 3) have a long-lasting   */
/*     condition that limits his or her ability to move his or her  */
/*     arms or legs?                                                */
  @1736 ERUNPLAY 2. /* CDQ: Condition limiting ability to walk/run/play */
/*     CDQ1C Does the child (age between 3 and 5) have a long-lasting   */
/*     condition that limits his or her ability to walk, run, or play?  */
  @1739 ESKOOLWK 2. /* CDQ: Physical/learning/mental condition and schoolwork */
/*     CDQ3 Because of a physical, learning, or mental condition, does  */
/*     the child (age between 6 and 19) have any limitations in his or  */
/*     her ability to do regular school work?                           */ 

/* Following questions on special education services DID exist in the */
/* 1993 SIPP Topical Module but were NOT used when defining KDISAB.   */
/* (Similar questions existed and were used for kids less than 6.)    */
  @1742 ESPECED  2. /* CDQ: Ever received special education services */
/*     CDQ4 Has the child (age between 6 and 19) ever received       */
/*     special education services?                                   */
  @1745 ESPEDNOW 2. /* CDQ: Currently receiving special education services */
/*     CDQ5 Is the child (age between 6 and 19) currently receiving  */
/*     special education services?                                   */

/* Specific questions about mental/learning limitations did    */
/* not exist in the 1993 SIPP Topical Module, but questions to */
/* identify specific conditions DID exist and were not used.   */
  @1748 ELERNDIS 2. /* CDQ: Learning disability like dyslexia        */
/*     CDQ6@1 Does the child (age between 6 and 14) have a learning  */
/*     disability such as dyslexia?                                  */
  @1751 KEMR     2. /* CDQ: Mental retardation                   */
/*     CDQ6@2 Does the child (age between 6 and 14) have mental  */
/*     retardation?                                              */
  @1754 KEDEVDIS 2. /* CDQ: Developmental disability              */
/*     CDQ6@3 Does the child (age between 6 and 14) have a        */
/*     developmental disability such as autism or cerebral palsy? */
  @1757 EOTHERDC 2. /* CDQ: Other developmental condition           */
/*     CDQ6@4 Does the child (age between 6 and 14) have any other  */ 
/*     developmental condition for which he or she has received     */
/*     therapy or diagnostic services?                              */

/* None of the following questions existed for the 1993 SIPP TM */ 
  @1760 KECANE   2. /* CDQ7@1: Use of a cane/crutches/walker    */
/*     CDQ7@1 Does the child (age between 6 and 14) use a cane, */
/*     crutches, or a walker?                                   */
  @1763 KEWCHAIR 2. /* CDQ: Use of a wheelchair or an electric scooter */
/*     CDQ7@2 Does the child (age between 6 and 14) use a wheelchair   */
/*     or an electric scooter?                                         */ 
  @1766 KEHEARAD 2. /* CDQ: Use of a hearing aid                       */
/*     CDQ7@3 Does the child (age between 6 and 14) use a hearing aid? */
  @1769 KECANE6  2. /* CDQ: Use of a cane/crutches/walker for six months */
/*     CDQ8 Has the child (age between 6 and 14) used a cane, crutches,  */
/*     or a walker for six months or longer?                             */
  @1772 KESEEDIF 2. /* CDQ9: Difficulty seeing words/letters      */
/*     CDQ9 Does the child (age between 6 and 14) have difficulty */
/*     seeing the words and letters in ordinary newspaper print,  */
/*     even when wearing glasses or contact lenses if he/she      */
/*     usually wears them?                                        */
  @1775 KESEENOT 2. /* CDQ: Ability to see ordinary newspaper print at all */
/*     CDQ10 Is the child (age between 6 and 14) able to see the words     */
/*     and letters in ordinary newspaper print at all?                     */
  @1778 KEHEARDF 2. /* CDQ: Difficulty hearing                     */
/*     CDQ11 Does the child (age between 6 and 14) have difficulty */
/*     hearing what is said in normal conversation with another    */
/*     person (even when wearing his or her hearing aid)?          */ 
  @1781 KEHEARNT 2. /* CDQ: Ability to hear at all                 */
/*     CDQ12 Is the child (age between 6 and 14) able to hear what */
/*     is said in a normal conversation at all?                    */
  @1784 KESPECHD 2. /* CDQ: Difficulty having speech understood */
/*     CDQ13 Does the child (age between 6 and 14) have any     */
/*     difficulty having his/her speech understood?             */
  @1787 KESPECHC 2. /* CDQ: Having speech understood at all */
/*     CDQ14 In general, are people able to understand the  */
/*     child's (age between 6 and 14) speech at all?        */ 

/* Similar to a variable used in 1993 */
  @1790 ESPORTS  2. /* CDQ: Condition limiting running/walking/sports/games */
/*     CDQ15 Does the child (age between 6 and 14) have a long-lasting */
/*     condition that limits his/her ability to walk, run or take part */
/*     in sports and games?                                            */

/* These questions did not exist in 1993 */
  @1793 KEINDIF  2. /* CDQ: Getting around inside the home          */
/*     CDQ16 Because of a long-lasting physical or mental condition */
/*     does the child (age between 6 and 14) have any difficulty    */
/*     getting around INSIDE the home by himself/herself?           */ 
  @1796 KEINHELP 2. /* CDQ: Needs help getting around inside the home  */
/*     CDQ17 Does the child (age between 6 and 14) need the help of    */
/*     another person with getting around inside the home?             */ 
  @1799 KEBEDDIF 2. /* CDQ:  Difficulty getting in/out of a bed/chair  */
/*     CDQ18 Does the child (age between 6 and 14) have any difficulty */ 
/*     getting in and out of bed or a chair by himself/herself?        */
  @1802 KEBEDHLP 2. /* CDQ: Needs help getting in/out of a bed/chair */
/*     CDQ19 Does the child (age betwen 6 and 14) need the help of   */
/*     another person with getting in and out of bed or a chair?     */ 
  @1805 KEBATHDF 2. /* CDQ: Difficulty taking a bath or a shower */
/*     CDQ20 Does the child (age between 6 and 14) have any      */
/*     difficulty taking a bath or shower by himself/herself?    */
  @1808 KEBATHH  2. /* CDQ: Needs help taking a bath or a shower */
/*     CDQ21 Does the child (age between 6 and 14) need the help */
/*     of another person with taking a bath or shower?           */ 
  @1811 KEDRESSD 2. /* CDQ: Difficulty putting on clothes       */
/*     CDQ22 Because of a long-lasting condition does the child */
/*     (age between 6 and 14) have any difficulty putting on    */
/*     clothing by himself/herself?                             */
  @1814 KEDRESSH 2. /* CDQ: Needs help putting on clothes       */
/*     CDQ23 Does the child (age between 6 and 14) need the     */
/*     help of another person with putting on his/her clothing? */
  @1817 KEEATDIF 2. /* CDQ: Difficulty eating food          */
/*     CDQ24 Does the child (age between 6 and 14) have any */
/*     difficulty eating food by him/herself?               */
  @1820 KEEATHLP 2. /* CDQ: Needs help eating food       */
/*     CDQ25 Does the child (age between 6 and 14) need  */
/*     the help of another person with eating food?      */
  @1823 KETOILTD 2. /* CDQ:  Difficulty using or getting to the toilet */
/*     CDQ26 Does the child (age between 6 and 14) have any difficulty */
/*     using or getting to the toilet by himself/herself?              */
  @1826 KETOILTH 2. /* CDQ:  Needs help using or getting to the toilet */
/*     CDQ27 Does the child (age between 6 and 14) need the help of    */
/*     another person with using or getting to the toilet?             */
  @1829 KESOCIAL 2. /* CDQ: Difficulty playing/getting along with children */
/*     CDQ28 Does the child (age between 6 and 14) have an emotional or    */ 
/*     mental condition that makes it difficult to play with or get        */
/*     along with other children of the same age?                          */

/* The fololwing questions identify specific conditions. */ 
  @1832 EKCOND1  2. /* CDQ: First condition causing difficulty       */
/*     CDQ29@1 I have recorded that the child (age between 6 and 14) */ 
/*     has difficulty with certain activities.  Which condition or   */
/*     conditions cause this difficulty?                             */
  @1835 EKCOND2  2. /* CDQ29@2: Second condition causing difficulty  */
  @1837 EKCOND3  2. /* CDQ29@3: Third condition causing difficulty   */
  @1839 KEMOTORV 2. /* CDQ: Any condition a result of motor vehicle accident */
/*     CDQ30 Are any of these conditions (child age between 6 and 14)        */
/*     the result of a motor vehicle accident?                               */
 ;

/* Select only the children */
/* Kid disability variable have values ONLY when EPCDUNV=1 */
/* There are a few kids < 20 with EPCDUNV not =1: they all */
/* have no mom/dad/guardian in their household to provide  */
/* data on their disability status and, hence, have no data*/
 if epcdunv eq 1;

/* For all kids in the Topical Module, mark as not being disabled. */
 length kdisab 3;
 kdisab=0;

/* If any of the conditions used in the 1993 SIPP Topical Module */
/* are indicated, mark the child as disabled.                    */
 if EDDELAY  eq 1 or ESKOOLWK eq 1 or
    ERUNPLAY eq 1 or ESPORTS eq 1
 then kdisab=1;

/* Create an ID for this child */
 syear='96';
 id1='000000000000';
 id1=ppid;
 id3='0000';
 id3=pppnum;
 sunique=syear||id1||id3;

run;

title 'Disability & Non-Disability information for all kids';
proc freq; tables kdisab;
run;

proc contents;
proc means;
run;

options obs=200;
title 'First 200 records of Disability Data';
proc print;
endsas;
