options linesize=80 nocenter pagesize=66;
options formdlim=' ' nodate nonumber;

/* Compute Eligibility Criteria for Children */

/* Lara's code to compute POVKID,POVINF by state & date:*/
/* At bottom, creates AGEEL,MEDLEV,EL40M,EL30M per kid. */

/* Get Medicaid and SCHIP eligibility criteria */
/* From start of non-AFDC expansions in 1987 through July 2005 */
/* Sources: Pre-SCHIP from National Governors' Association, */
/* esp. MCH Updates.  SCHIP from CMS Fact Sheets */
/* and NGA's state SCHIP summaries. */
/* Other sources include some Kaiser Commission on Medicaid */
/* and the Uninsured reports, the appendix to my chapter from */
/* the Changing Welfare book, HHS press releases, and for really */
/* difficult cases, web searches for state-specific information. */
/* Note that there are some discrepancies, even between sources */
/* that are nominally the same, such as the NGA.  In those cases, */
/* I chose the source that seemed most likely to be correct based */
/* on the state's historical record and my experience with expansions. */
/* Some notes on dates: I used the expansion or state plan start date */
/* if that was available, I used the HHS approval or state law passage */
/* date next, and if neither was available I used the known date of the */
/* NGA report.  If a date was mid-month, I used the following month to */
/* start.  If the start date was retroactive, I used the approval date, since */
/* families would not have been able to report getting insurance retroactively.*/
/* Date: June 2006 */

libname kids 'c:\lara\papers\Dynamic\child\duration\mar02\ERIU\kids\';
libname xportin xport 'c:\lara\papers\Dynamic\child\duration\mar02\ERIU\kids\kids96.xpt';
*libname target 'c:\lara\papers\Dynamic\child\duration\mar02\ERIU\kids\';

data kids.newkids96;
   set xportin.kids96;
run;

data kids.newkids96;
set kids.newkids96;

/* make child's birthdate */
if ubrthyr<2000 then brthyr=ubrthyr-1900;
if ubrthyr>=2000 then brthyr=ubrthyr;
birthday=(brthyr*100)+ubrthmn;

/*fix date to account for 2000's*/
if date<8000 then date=date+200000;

povkid=0;
povinf=0;

if date>=8907 and date<9004 then povinf=75;
if date>=9004 then povinf=133;

if date>=9004 and age<6 then povkid=133;
if date>=9107 and birthday>=8310 and (age>=6 and age<19) then povkid=100;

/* Alabama, 63 */
if (date>=8807 and date<8907) and cpstate=63 then povinf=100 ;
if date>=9910 and cpstate=63 then povinf=200;

if (date>=9802 and date<9910) and (age>=6 and age<19) and cpstate=63 then povkid=100;
if date>=9910 and (age>=1 and age<19) and cpstate=63 then povkid=200;

/* Alaska, 94 */
if (date>=8901 and date<9004) and cpstate=94 then povinf=100;
if (date>=9903 and date<200310) and cpstate=94 then povinf=200;
if date>=200310 and cpstate=94 then povinf=175;

if (date>=8901 and date<9004) and (birthday>=8901) and (age<5) and
 cpstate=94 then povkid=100;
if (date>=9903 and date<200310) and (age>=1 and age<19) and cpstate=94 then povkid=200; 
if date>=200310 and (age>=1 and age<19) and cpstate=94 then povkid=175;

/* Arizona, 86*/
if (date>=8801 and date<9004) and cpstate=86 then povinf=100;
if (date>=9010 and date<9810) and cpstate=86 then povinf=140;
if (date>=9810 and date<9910) and cpstate=86 then povinf=150;
if date>=9910 and cpstate=86 then povinf=200;

if (date>=8801 and date<9004) and (birthday>=8701) and (age<2) and
cpstate=86 then povkid=100;

if (date>=9004 and date<9107) and (birthday>=8310 and
 birthday<8504) and (age>=6 and age<8) and cpstate=86 then povkid=100;
if (date>=9207 and date<9810) and (birthday>=7901 and birthday<8310) and
 (age<14) and cpstate=86 then povkid=100;
if (date>=9810 and date<9910) and (age>=1 and age<19) and cpstate=86 then povkid=150;
if date>=9910 and (age>=1 and age<19) and cpstate=86 then povkid=200; 


/* Arkansas, 71*/
if (date>=8704 and date<8807) and cpstate=71 then povinf=75;
if (date>=8807 and date<8907) and cpstate=71 then povinf=100;
if (date>=8907 and date<9004) and cpstate=71 then povinf=100;
if (date>=9103 and date<9205) and cpstate=71 then povinf=185;
if (date>=9205 and date<9710) and cpstate=71 then povinf=133;
if date>=9710 and cpstate=71 then povinf=200;

if (date>=8704 and date<8807) and (birthday>=8604) and (age<5) and
cpstate=71 then povkid=75;
if (date>=8807 and date<8910) and (birthday>=8407) and (age<5) and
cpstate=71 then povkid=100;
if (date>=8910 and date<9004) and (birthday>=8310) and (age<7) and
cpstate=71 then povkid=100;
if (date>=9101 and date<9107) and (birthday>=8310) and (age<7) and
cpstate=71 then povkid=100;
if date>=9710 and (age>=1 and age<19) and cpstate=71 then povkid=200;


/* California, 93 */
if (date>=8907 and date<9004) and cpstate=93 then povinf=185;
if (date>=9004 and date<9804) and cpstate=93 then povinf=200;
/*state-funded program*/
if (date>=9804 and date<9912) and cpstate=93 then povinf=250;
if date>=9912 and cpstate=93 then povinf=250;

if (date>=9007 and date<9107) and (birthday>=8310) and cpstate=93 then povkid=100;
if (date>=9207 and date<9407) and (age>=1 and age<19) and cpstate=93 then povkid=200;
/*this is a state-funded program only for preventive services*/
/* and it appears to last only a short time*/
if (date>=9804 and date<9912) and (age>=1 and age<19) and cpstate=93 then povkid=200;
if date>=9912 and (age>=1 and age<19) and cpstate=93 then povkid=250;

/* Colorado, 84 */
if (date>=8907 and date<9004) and cpstate=84 then povinf=75;
if date>=9803 and cpstate=84 then povinf=185;

if date>=9803 and (age>=1 and age<19) and cpstate=84 then povkid=185;
     

/* Connecticut, 16 */
if (date>=8804 and date<8807) and cpstate=16 then povinf=100;
if (date>=8807 and date<9804) and cpstate=16 then povinf=185;

if date>=9804 and cpstate=16 then povinf=300;

if (date>=8711 and date<9004) and (birthday>=8707) and (age<5) and
cpstate=16 then povkid=100;
if (date>9307 and date<9804) and (age<6) and cpstate=16 then povkid=185;
if (date>=9407 and date<9804) and (birthday>=8310) and cpstate=16 then povkid=185;
if date>=9804 and (age>=1 and age<19) and cpstate=16 then povkid=300;

/* Delaware, 51 */
if (date>=8801 and date<9004) and cpstate=51 then povinf=100;
if (date>=9107 and date<9210) and cpstate=51 then povinf=160;
if (date>=9210 and date<9810) and cpstate=51 then povinf=185;
if date>=9810 and cpstate=51 then povinf=200;

if (date>=8807 and date<9004) and (birthday>=8707) and (age<2) and
 cpstate=51 then povkid=100;
if (date>=9007 and date<9107) and (birthday>=8310) and cpstate=51 then
 povkid=100;
if (date>=9210 and date<9810) and (age>=1 and age<19) and cpstate=51 then povkid=100;
if date>=9810 and (age>=1 and age<19) and cpstate=51 then povkid=200;

/* DC, 53 */
if (date>=8704 and date<9004) and cpstate=53 then povinf=100;
if (date>=9004 and date<9810) and cpstate=53 then povinf=185;
if date>=9810 and cpstate=53 then povinf=200;

if (date>=8807 and date<9004) and (birthday>=8707) and (age<3) and
 cpstate=53 then povkid= 100;
if (date>=9004 and date<9107) and (birthday>=8310 and
 birthday<8504) and (age<8) and cpstate=53 then povkid=100;
if date>=9810 and cpstate=53 and (age>=1 and age<19) then povkid=200; 


/* Florida, 59 */
if (date>=8710 and date<9001) and cpstate=59 then povinf=100;
if (date>=8907 and date<9205) and cpstate=59 then povinf=150;
if (date>=9205 and date<9803) and cpstate=59 then povinf=185;
if date>=9803 and cpstate=59 then povinf=200;

if (date>=8710 and date<8810) and (birthday>=8610) and (age<2) and
cpstate=59 then povkid=100;
if (date>=8810 and date<9004) and (birthday>=8410) and (age<8) and
cpstate=59 then povkid=100;
if (date>=9004 and date<9107) and (birthday>=8410) and (age<8) and
cpstate=59 then povkid=100;
if (date>=9501 and date<9803) and (age>=1 and age<20) and cpstate=59 then povkid=100;
if date>=9803 and (age>=1 and age<19) and cpstate=59 then povkid=200;
    

/* Georgia, 58 */
if (date>=8901 and date<9004) and cpstate=58 then povinf=100;
if (date>=9004 and date<9301) and cpstate=58 then povinf=133;
if (date>=9301 and date<9307) and cpstate=58 then povinf=150;
if (date>=9307 and date<9809) and cpstate=58 then povinf=185;
if date>=9809 and cpstate=58 then povinf=235;

if (date>=8901 and date<9004) and (birthday>=8710) and cpstate=58 then povkid=100;
if (date>9307 and date<9809) and (age>=1 and age<19) and cpstate=58 then povkid=100;
if date>=9809 and (age>=1 and age<19) and cpstate=58 then povkid=235; 

/* Hawaii, 95 */
if date>=8901 and date<9001 and cpstate=95 then povinf=100;
if (date>=9001 and date<9301) and cpstate=95 then povinf=185;
if date>=9301 and cpstate=95 then povinf=300;

if (date>=8901 and date<9001) and (birthday>=8901) and (age<5) and
 cpstate=95 then povkid=100;
if (date>=9001 and date<9004) and (birthday>=8310) and (age<8) and
cpstate=95 then povkid=100;
if (date>=9004 and date<9107) and (birthday>=8310 and 
 birthday<8504) and (age<8) and cpstate=95 then povkid=100;
if date>=9301 and (age>=1 and age<19) and cpstate=95 then povkid=300; 
/*state-sponsored/waiver program*/
/*Note that while Hawaii's QUEST program allows kids up to 300% of poverty,*/
/* at least post-SCHIP they have to have qualified for Medicaid or SCHIP */
/*  first and experience a family income increase.  Also, the family must */
/*  cover the premium cost.  Otherwise, the income limits are standard, plus */
/*  if date>=9710 and birthday<8310 and age<19 and cpstate=95 then povkid=100.*/
/* if date>=200010 and cpstate=95 then povinf=200. SCHIP starts*/
/*if date>=200010 and (age>=1 and age<19) and cpstate=95 then povkid=200*/

/* Idaho, 82 */
if (date>=8901 and date<8907) and cpstate=82 then povinf=67;
if (date>=8907 and date<9004) and cpstate=82 then povinf=75;
if date>=9807 and cpstate=82 then povinf=150;

if date>=9807 and (age>=1 and age<19) and cpstate=82 then povkid=150;

/* Illinois, 33 */
if (date>=8807 and date<9004) and cpstate=33 then povinf=100;
if (date>=9810 and date<200307) and cpstate=33 then povinf=185;
if date>=200307 and cpstate=33 then povinf=200;

if (date>=9804 and date<9810) and (age>=1 and age<19) and cpstate=33 then povkid=133;
if (date>=9810 and date<200307)  and (age>=1 and age<19) and cpstate=33 then povkid=185;
if date>=200307 and (age>=1 and age<19) and cpstate=33 then povkid=200;

/* Indiana, 32 */
if (date>=8807 and date<8907) and cpstate=32 then povinf=50;
if (date>=8907 and date<9004) and cpstate=32 then povinf=100;
if (date>=9107 and date<200001) and cpstate=32 then povinf=150;
if date>=200001 and cpstate=32 then povinf=200;

if (date>=8907 and date<9004) and (birthday>=8707) and (age<3) and
cpstate=32 then povkid=100;
if (date>=9806 and date<200001) and (age>=1 and age<19) and cpstate=32 then povkid=150; 
if date>=200001 and (age>=1 and age<19) and cpstate=32 then povkid=200;    

/* Iowa, 42 */
if (date>=8901 and date<8907) and cpstate=42 then povinf=150;
if (date>=8907 and date<200007)and cpstate=42 then povinf=185;
if date>=200007 and cpstate=42 then povinf=200;

if (date>=8901 and date<8907) and (birthday>=8801) and cpstate=42 then povkid=100;
if (date>=8907 and date<9004) and (birthday>=8407) and (age>=1 and age<8) and
 cpstate=42 then povkid=100;
if (date>=9004 and date<9107) and (birthday>=8407 and 
 birthday<8504) and (age<8) and cpstate=42 then povkid=100;
if (date>=9807 and date<9901) and (age>=1 and age<19) and cpstate=42 then povkid=133;
if (date>=9901 and date<200007) and (age>=1 and age<19) and cpstate=42 then povkid=185;
if date>=200007 and (age>=1 and age<19) and cpstate=42 then povkid=200;

/* Kansas, 47 */
if (date>=8807 and date<8907) and cpstate=47 then povinf=100;
if (date>=8907 and date<9809) and cpstate=47 then povinf=150;
if date>=9809 and cpstate=47 then povinf=200;

if (date>=8907 and date<9004) and (birthday>=8507) and (age<5) and
cpstate=47 then povkid=100;
if (date>=9501 and date<9609) and (age>=6 and age<15) and cpstate=47 then povkid=100;
if (date>=9609 and date<9809) and (age>=6 and age<17) and cpstate=47 then povkid=100;
if date>=9809 and (age>=1 and age<19) and cpstate=47 then povkid=200;


/* Kentucky, 61 */
if (date>=8710 and date<8807) and cpstate=61 then povinf=100;
if (date>=8807 and date<9004) and cpstate=61 then povinf=125;
if (date>=9007 and date<9812) and cpstate=61 then povinf=185;
if date>=9812 and cpstate=61 then povinf=200;

if (date>=8710 and date<9004) and (birthday>=8610) and (age<2) and
cpstate=61 then povkid=100;
if (date>=9501 and date<9812) and (age>=1 and age<19) and cpstate=61 then povkid=100;
if date>=9812 and (age>=1 and age<19) and cpstate=61 then povkid=200;

/* Louisiana, 72 */
if (date>=8901 and date<9004) and cpstate=72 then povinf=100;
if (date>=9811 and date<200110) and cpstate=72 then povinf=150;
if date>=200110 and cpstate=72 then povinf=200;

if (date>=8901 and date<9004) and (birthday>=8310) and (age<8) and
cpstate=72 then povkid=100;
if (date>=9004 and date<9107) and (birthday>=8310 and 
 birthday<8504) and (age<8) and cpstate=72 then povkid=100;
if (date>=9811 and date<200110) and (age>=1 and age<19) and cpstate=72 then povkid=150;
if date>=200110 and (age>=1 and age<19) and cpstate=72 then povkid=200;

/* Maine, 11 */
if (date>=8810 and date<200103) and cpstate=11 then povinf=185;
if date>=200103 and cpstate=11 then povinf=200;

if (date>=8810 and date<9004) and (birthday>=8410) and (age<5) and
cpstate=11 then povkid=100;
if (date>=9007 and date<9107) and (birthday>=8310) 
 and cpstate=11 then povkid=100;
if (date>=9010 and date<9807) and (age>=6 and age<19) and cpstate=11 then povkid=125;
*state-funded program;
if (date>=9807 and date<9808) and (age>=1 and age<19) and cpstate=11 then povkid=150;
if (date>=9808 and date<200103) and (age>=1 and age<19) and cpstate=11 then povkid=185;
if date>=200103 and (age>=1 and age<19) and cpstate=11 then povkid=200;

/* Maryland, 52 */
if (date>=8707 and date<8906) and cpstate=52 then povinf=100;
if (date>=8906 and date<9801) and cpstate=52 then povinf=185;
if (date>=9801 and date<200107) and cpstate=52 then povinf=200;
if date>=200107 and cpstate=52 then povinf=300;

if (date>=8707 and date<8906) and (birthday>=8707) and (age<5) and
 cpstate=52 then povkid=100;
if (date>=9307 and date<9801) and age>=1 and birthday>=8310 and 
 cpstate=52 then povkid=185;
if (date>=9801 and date<200107) and (age>=1 and age<19) and cpstate=52 then povkid=200;
if date>=200107 and (age>=1 and age<19) and cpstate=52 then povkid=300;

/* Massachusetts, 14 */
if (date>=8707 and date<8807) and cpstate=14 then povinf=100;
if (date>=8807 and date<9809) and cpstate=14 then povinf=185;
if date>=9809 and cpstate=14 then povinf=200;

if (date>=8707 and date<8807) and (birthday>=8707) and (age<5) and
cpstate=14 then povkid=100;
if (date>=8807 and date<9004) and (birthday>=8407) and (age<5) and
cpstate=14 then povkid=100;
if (date>=9301 and date<9809) and (age<6) and cpstate=14 then povkid=200; 
/*state-sponsored program*/
if (date>=9701 and date<9809) and (age>=6 and age<19) and cpstate=14 then povkid=133;
if date>=9809 and (age>=1 and age<19) and cpstate=14 then povkid=200;


/* Michigan, 34 */
if (date>=8801 and date<8807) and cpstate=34 then povinf=100;
if (date>=8807 and date<9805) and cpstate=34 then povinf=185;
if date>=9805 and cpstate=34 then povinf=200;

if (date>=8801 and date<9004) and (birthday>=8701) and (age<5) and
 cpstate=34 then povkid=100;
if (date>=9501 and date<9801) and birthday>=8310 and age<19 and cpstate=34 then
povkid=150;
if date>=9805 and (age>=1 and age<19) and cpstate=34 then povkid=200;
/*there is some question about ages in Michigan.  MCH Update is vague.*/

/* Minnesota, 41 */
if (date>=8807 and date<9307) and cpstate=41 then povinf=185;
if (date>=9307 and date<9810) and cpstate=41 then povinf=275;
if date>=9810 and cpstate=41 then povinf=280;

if (date>=8907 and date<9004) and (birthday>=8310) and (age<7) and
 cpstate=41 then povkid=100;
if (date>=9004 and date<9107) and (birthday>=8310 and
 birthday<8504) and (age<7) and cpstate=41 then povkid=100;
if (date>=9210 and date<9301) and (age>=1 and age<18) and cpstate=41 then povkid=185;
if (date>=9301 and date<9810) and (age>=1 and age<19) and cpstate=41 then povkid=275;
*state-sponsored program;
if date>=9810 and (age>=1 and age<3) and cpstate=41 then povkid=280;
if date>=9810 and (age>=3 and age<21) and cpstate=41 then povkid=275;


/* Mississippi, 64 */
if (date>=8710 and date<8807) and cpstate=64 then povinf=100;
if (date>=8807 and date<9907) and cpstate=64 then povinf=185;
if date>=9907 and cpstate=64 then povinf=200;

if (date>=8710 and date<8810) and (birthday>=8610) and (age<5) and
 cpstate=64 then povkid=100;
if (date>=8907 and date<9004) and (birthday>=8507) and (age<5) and
 cpstate=64 then povkid=100;
if (date>=9807 and date<9901) and (age>=6 and age<19) and cpstate=64 then povkid=100;
if (date>=9901 and date<9907) and (age>=6 and age<19) and cpstate=64 then povkid=133;
if date>=9907 and (age>=1 and age<19) and cpstate=64 then povkid=200;

/* Missouri, 43 */
if (date>=8801 and date<9004) and cpstate=43 then povinf=100;
if (date>=9401 and date<9805) and cpstate=43 then povinf=185;
if date>=9805 and cpstate=43 then povinf=300;

if (date>=8801 and date<8810) and (birthday>=8710) and (age<2) and
 cpstate=43 then povkid=100;
if (date>=8810 and date<9004) and (birthday>=8610) and (age<3) and
 cpstate=43 then povkid=100;

if (date>=9401 and date<9501) and (age>=1 and age<18) and cpstate=43 then povkid=100;
if (date>=9501 and date<9805) and (age>=1 and age<19) and cpstate=43 then povkid=100;
if date>=9805 and (age>=1 and age<19) and cpstate=43 then povkid=300;

/* Montana, 81 */
if (date>=8907 and date<9004) and cpstate=81 then povinf=100;
if date>=9901 and cpstate=81 then povinf=150;

if (date>=9007) and (birthday>=8310) and (age>=6 and age<8) and
cpstate=81 then povkid=100;
if date>=9901 and (age>=1 and age<19) and cpstate=81 then povkid=150;

/* Nebraska, 46 */
if (date>=8807 and date<9004) and cpstate=46 then povinf=100;
if (date>=9501 and date<9805) and cpstate=46 then povinf=150;
if date>=9805 and cpstate=46 then povinf=185;

if (date>=8807 and date<9004) and (birthday>=8310) and (age<5) and
cpstate=46 then povkid=100;
if date>=9805 and (age>=1 and age<19) and cpstate=46 then povkid=185;

/* Nevada, 88 */
if (date>=8907 and date<9004) and cpstate=88 then povinf=75;
if date>=9810 and cpstate=88 then povinf=200;

if date>=9810 and (age>=1 and age<19) and cpstate=88 then povkid=200;

/* New Hampshire, 12 */
if (date>=8907 and date<9004) and cpstate=12 then povinf=75;
if (date>=9207 and date<9401) and cpstate=12 then povinf=150;
if (date>=9401 and date<9501) and cpstate=12 then povinf=170;
if (date>=9501 and date<9810) and cpstate=12 then povinf=185;
if date>=9810 and cpstate=12 then povinf=300;

if (date>=9401 and date<9407) and (age>=1 and age<11) and cpstate=12 then povkid=170;
if (date>=9407 and date<9801) and (age>=1 and age<19) and cpstate=12 then povkid=185;
if date>=9801 and (age>=1 and age<19) and cpstate=12 then povkid=185;

/* New Jersey, 22 */
if (date>=8707 and date<9004) and cpstate=22 then povinf=100;
if (date>=9107 and date<9401) and cpstate=22 then povinf=185;
if (date>=9401 and date<9509) and cpstate=22 then povinf=300;
/*state-funded program*/
if (date>=9509 and date<9803) and cpstate=22 then povinf=185;
if (date>=9803 and date<9909) and cpstate=22 then povinf=200;
if date>=9909 and cpstate=22 then povinf=350;

if (date>=8801 and date<9004) and (birthday>=8701) and (age<2) and
cpstate=22 then povkid=100;
if (date>=9802 and date<9803) and (age>=1 and age<19) and cpstate=22 then povkid=133;
if (date>=9803 and date<9909) and (age>=1 and age<19) and cpstate=22 then povkid=200;
if date>=9909 and (age>=1 and age<19) and cpstate=22 then povkid=350;

/* New Mexico, 85 */
if (date>=8801 and date<9004) and cpstate=85 then povinf=100;
if (date>=9107 and date<9903) and cpstate=85 then povinf=185;
if date>=9903 and cpstate=85 then povinf=235;

if (date>=8801 and date<8810) and (birthday>=8701) and (age<2) and
 cpstate=85 then povkid=100;
if (date>=8810 and date<9004) and (birthday>=8610) and (age<5) and
 cpstate=85 then povkid=100;
if (date>=9501 and date<9903) and (age>=1 and age<19) and cpstate=85 then povkid=185;
if date>=9903 and (age>=1 and age<19) and cpstate=85 then povkid=235;


/* New York, 21 */
if (date>=8907 and date<9910) and cpstate=21 then povinf=185;
if (date>=9910 and date<200108) and cpstate=21 then povinf=192;
if date>200108 and cpstate=21 then povinf=250;

if (date>=9107 and date<9407) and (age>=1 and age<13) and cpstate=21 then povkid=185;
if (date>=9407 and date<9509) and (age>=1 and age<13) and cpstate=21 then povkid=160;
if (date>=9509 and date<9805) and birthday>=8310 and age<19 and cpstate=21 then
povkid=100;
if (date>=9805 and date<9910) and (age>=1 and age<19) and cpstate=21 then povkid=185;
if (date>=9910 and date<200108) and (age>=1 and age<19) and cpstate=21 then povkid=192;
if date>200108 and (age>=1 and age<19) and cpstate=21 then povkid=250;
/*NY is puzzling*/

/* North Carolina, 56 */
if (date>=8710 and date<9001) and cpstate=56 then povinf=100;
if (date>=9001 and date<9010) and cpstate=56 then povinf=150;
if (date>=9010 and date<9810) and cpstate=56 then povinf=185;
if date>=9810 and cpstate=56 then povinf=200;

if (date>=8710 and date<8910) and (birthday>=8610) and (age<5) and
 cpstate=56 then povkid=100;
if (date>=8910 and date<9004) and (birthday>=8410) and (age<7) and
 cpstate=56 then povkid=100;
if (date>=9004 and date<9107) and (birthday>=8310) and cpstate=56 
 then povkid=100;
if (date>=9609 and date<9810) and (age>=6 and age<19) and cpstate=56 then povkid=100; 
if date>=9810 and (age>=1 and age<19) and cpstate=56 then povkid=200;

/* North Dakota, 44 */
if (date>=8907 and date<9004) and cpstate=44 then povinf=75;
if date>=9809 and cpstate=44 then povinf=140;

if (date>=9501 and date<9809) and (age>=6 and age<18) and cpstate=44 then povkid=100;
if date>=9809 and (age>=1 and age<19) and cpstate=44 then povkid=140;

/* Ohio, 31 */
if (date>=8901 and date<9004) and cpstate=31 then povinf=100;
if (date>=9801 and date<200007) and cpstate=31 then povinf=150;
if date>=200007 and cpstate=31 then povinf=200;

if (date>=9801 and date<200007) and (age>=1 and age<19) and cpstate=31 then povkid=150;
if date>=200007 and (age>=1 and age<19) and cpstate=31 then povkid=200;

/* Oklahoma, 73 */
if (date>=8801 and date<9004) and cpstate=73 then povinf=100;
if (date>=9204 and date<9712) and cpstate=73 then povinf=150;
if date>=9712 and cpstate=73 then povinf=185;

if (date>=8801 and date<9004) and (birthday>=8701) and (age<4) and
 cpstate=73 then povkid=100;
if date>=9712 and (age>=1 and age<=17) and cpstate=73 then povkid=185;

/* Oregon, 92 */
if (date>=8711 and date<8809) and cpstate=92 then povinf=85;
if (date>=8809 and date<9004) and cpstate=92 then povinf=100;
if (date>=9807 and date<200211) and cpstate=92 then povinf=170;
if date>=200211 and cpstate=92 then povinf=185;

if (date>=8711 and date<9004) and (birthday>=8611) and (age<2) and
 cpstate=92 then povkid=85;
if (date>=8809 and date<9004) and (birthday>=8609) and (age<3) and
cpstate=92 then povkid=100;
if (date>9501 and date<9807) and (age>=1 and age<19) then povkid=100;
if (date>=9807 and date<200211) and (age>=1 and age<19) and cpstate=92 then povkid=170;
if date>200211 and (age>=1 and age<19) and cpstate=92 then povkid=185;

/* Pennsylvania, 23 */
if date>=8804 and date<9004 and cpstate=23 then povinf=100;
if (date>=9301 and date<9811) and cpstate=23 then povinf=185;
if (date>=9811 and date<200010) and cpstate=23 then povinf=200;
if date>=200010 and cpstate=23 then povinf=235;

if (date>=8804 and date<9004) and (birthday>=8610) and
 cpstate=23 then povkid=100;
if (date>=9304 and date<9407) and (age>=1 and age<6) and cpstate=23 then povkid=185;
if (date>=9304 and date<9407) and (age>=6 and age<12) and cpstate=23 then povkid=100;
if (date>=9407 and date<9509) and (age>=1 and age<14) and cpstate=23 then povkid=185;
/*state-funded program*/
if (date>=9806 and date<9811) and (age>=1 and age<17) and cpstate=23 then povkid=185;
if (date>=9811 and date<200010) and (age>=1 and age<19) and cpstate=23 then povkid=200;     
if date>=200010 and (age>=1 and age<19) and cpstate=23 then povkid=235;

/* Rhode Island, 15 */
if (date>=8704 and date<8810) and cpstate=15 then povinf=100;
if (date>=8810 and date<9501) and cpstate=15 then povinf=185;
if date>=9501 and cpstate=15 then povinf=250;

if (date>=8704 and date<8710) and (birthday>=8510) and cpstate=15 
 then povkid=100;
if (date>=8710 and date<8810) and (birthday>=8510) and cpstate=15 
 then povkid=100;
if (date>=8810 and date<8909) and (birthday>=8510) and cpstate=15 
 then povkid=100;
if (date>=8909 and date<9004) and (birthday>=8310) and cpstate=15 
 then povkid=100;
if (date>=9501and date<9805) and (age>=1 and age<7) and cpstate=15 then povkid=250;
if date>=9805 and (age>=1 and age<19) and cpstate=15 then povkid=250;

/*if date>=9901 and cpstate=15 then povinf=300;*/
/*if date>=9901 and (age>=1 and age<19) and cpstate=15 then povkid=300; */
/*RI never implemented due to budget constraints*/

/* South Carolina, 57 */
if date>=8710 and date<8907 and cpstate=57 then povinf=100;
if date>=8907 and cpstate=57 then povinf=185;

if (date>=8710 and date<9004) and (birthday>=8610) and (age<6) and
cpstate=57 then povkid=100;
if date>=9803 and (age>=1 and age<19) and cpstate=57 then povkid=150;


/* South Dakota, 45 */
if (date>=8807 and date<9004) and cpstate=45 then povinf=100;
if (date>=9911 and date<200012) and cpstate=45 then povinf=140;
if date>=200012 and cpstate=45 then povinf=200;

if (date>=8909 and date<9004) and (age>=1 and age<2) and cpstate=45 then povkid=100;
if (date>=9609 and date<9809) and (age>=6 and age<19) and cpstate=45 then povkid=100; 
if (date>=9809 and date<9911) and (age>=6 and age<19) and cpstate=45 then povkid=133;
if (date>=9911 and date<200012) and (age>=1 and age<19) and cpstate=45 then povkid=140;
if date>=200012 and (age>=1 and age<19) and cpstate=45 then povkid=200;

/* Tennessee, 62 */
if (date>=8707 and date<9004) and cpstate=62 then povinf=100;
if (date>=9007 and date<9107) and cpstate=62 then povinf=150;
if (date>=9107 and date<9401) and cpstate=62 then povinf=185;
if (date>=9401 and date<9501) and cpstate=62 then povinf=400;
if (date>=9501 and date<9704) and cpstate=62 then povinf=185;
if (date>=9704 and date<200210) and cpstate=62 then povinf=200;

if (date>=8707 and date<8807) and (birthday>=8610) and (age<2) and
 cpstate=62 then povkid=100;
if (date>=8807 and date<9004) and (birthday>=8407) and (age<6) and
 cpstate=62 then povkid=100;
if (date>=9401 and date<=9501) and (age>=1 and age<19) and cpstate=62 then povkid=400;
if (date>=9704 and date<9810) and (age>=1 and age<18) and cpstate=62 then povkid=400;
if (date>=9810 and date<200210) and (age>=1 and age<19) and cpstate=62 then povkid=400;
if date>=200210 and (age>=1 and age<19) and cpstate=62 then povkid=200;
/*TennCare closed enrollment, then reopened*/

/* Texas, 74 */
if (date>=8809 and date<8909) and cpstate=74 then povinf=100;
if (date>=8909 and date<9004) and cpstate=74 then povinf=130;
if (date>=9203 and date<200005) and cpstate=74 then povinf=185;
if date>=20005 and cpstate=74 then povinf=200;

if (date>=8809 and date<8909) and (birthday>=8709) and (age<2) and
 cpstate=74 then povkid=100;
if (date>=8909 and date<9004) and (birthday>=8609) and (age<6) and
 cpstate=74 then povkid=100;
if (date>=9807 and date<200005) and birthday<8310 and age<19 and cpstate=74 then  
povkid=100;
if date>=200005 and (age>=1 and age<19) and cpstate=74 then povkid=200;

/* Utah, 87 */
if (date>=8901 and date<9004) and cpstate=87 then povinf=100;
if date>=9808 and cpstate=87 then povinf=200;

if (date>=9501 and date<9808) and (age>=6 and age<18) and cpstate=87 then povkid=100;
if date>=9808 and (age>=1 and age<19) and cpstate=87 then povkid=200;

/* Vermont, 13 */
if (date>=8710 and date<8807) and cpstate=13 then povinf=100;
if (date>=8807 and date<9004) and cpstate=13 then povinf=200;
*state-funded program;
if (date>=9004 and date<9901) and cpstate=13 then povinf=225;
if date>=9901 and cpstate=13 then povinf=300;

if (date>=8710 and date<8807) and (birthday>=8610) and (age<2) and
 cpstate=13 then povkid=100;
if (date>=8807 and date<9004) and (birthday>=8407) and (age<6) and
 cpstate=13 then povkid=225;
if (date>=9004 and date<=9207) and (age>=1 and age<7) and cpstate=13 then povkid=225;
if (date>9207 and date<9901) and (age>=1 and age<18) and cpstate=13 then povkid=225;
if date>=9901 and (age>=1 and age<19) and cpstate=13 then povkid=300;


/* Virginia, 54 */
if (date>=8807 and date<9004) and cpstate=54 then povinf=100;
if (date>=9811 and date<200101) and cpstate=54 then povinf=185;
if date>=200101 and cpstate=54 then povinf=200;

if (date>=8909 and date<9004) and (age>=1 and age<2) and cpstate=54 then povkid=100;
if (date>=9307 and date<9811) and (age>=1 and age<19) and cpstate=54 then povkid=100;
if (date>=9811 and date<200101) and (age>=1 and age<19) and cpstate=54 then povkid=185;

if date>=200101 and (age>=1 and age<19) and cpstate=54 then povkid=200;

/* Washington, 91 */
if (date>=8707 and date<8908) and cpstate=91 then povinf=90;
if (date>=8908 and date<9004) and cpstate=91 then povinf=185;
if (date>=9004 and date<9407) and cpstate=91 then povinf=185;
if (date>=9407 and date<200001) and cpstate=91 then povinf=200;
if date>=200001 and cpstate=91 then povinf=250;

if (date>=8710 and date<8908) and (birthday>=8610) and (age<2) and
 cpstate=91 then povkid=90;
if (date>=8908 and date<9004) and (birthday>=8310) and (age<8) and
 cpstate=91 then povkid=100;
if (date>=9004 and date<9101) and (birthday>=8310) and cpstate=91 
 then povkid=100;
if (date>=9101 and date<9407) and (age>=6 and age<19) and cpstate=91 then povkid=100;
if (date>=9407 and date<200001) and (age>=1 and age<19) and cpstate=91 then povkid=200;
if date>=200001 and (age>=1 and age<19) and cpstate=91 then povkid=250;

/* West Virginia, 55 */
if (date>=8707 and date<8807) and cpstate=55 then povinf=100;
if (date>=8807 and date<9501) and cpstate=55 then povinf=150;
if (date>=9501 and date<9810) and cpstate=55 then povinf=133;
if (date>=9810 and date<200011) and cpstate=55 then povinf=150;
if date>=200011 and cpstate=55 then povinf=200;

if (date>=8707 and date<8807) and (birthday>=8707) and (age<5) and
 cpstate=55 then povkid=100;
if (date>=8807 and date<9004) and (birthday>=8310) and (age<8) and
 cpstate=55 then povkid=100;
if (date>=9307 and date<9501) and (age>=1 and age<21) and cpstate=55 then povkid=150;
if (date>=9501 and date<9810) and (age>=6 and age<19) and cpstate=55 then povkid=100;
if (date>=9810 and date<9904) and (age>=1 and age<6) and cpstate=55 then povkid=150;
if (date>=9904 and date<200011) and (age>=1 and age<19) and cpstate=55 then povkid=150;
if date>=200011 and (age>=1 and age<19) and cpstate=55 then povkid=200;

/* Wisconsin, 35 */
if (date>=8804 and date<8908) and cpstate=35 then povinf=120;
if (date>=8908 and date<9004) and cpstate=35 then povinf=130;
if (date>=9007 and date<9501) and cpstate=35 then povinf=155;
if date>=9501 and cpstate=35 then povinf=185;
*state-funded programs;

if (date>=9007) and (age>=1 and age<6) and cpstate=35 then povkid=155;
if (date>=9501 and date<9807) and (age>=1 and age<6) and cpstate=35 then povkid=185;
if date>=9807 and (age>=1 and age<19) and cpstate=35 then povkid=185;
/*once enrolled in WI plan, can stay enrolled if income rises to 200% of poverty*/

/* Wyoming, 83 */
if (date>=8810 and date<9004) and cpstate=83 then povinf=100;
if (date>=9911 and date<200501) and cpstate=83 then povinf=133;
if date>=200501 and cpstate=83 then povinf=200;

if (date>=9911 and date<200501) and (age>=1 and age<19) and cpstate=83 then povkid=133;
if date>=200501 and (age>=1 and age<19) and cpstate=83 then povkid=200;


*make sure all of the national-level variables did not get reduced;
if povinf<75 and date>=8907 and date<9004 then povinf=75;
if povinf<133 and date>=9004 then povinf=133;

if povkid<133 and (date>=9004) and (age<6) then povkid=133;
if povkid<100 and (date>=9107) and (birthday>=8310) and (age<19)
 then povkid=100;

ageel=0;
if (povkid>0 or (povinf>0 and age<1)) then ageel=1;

if age<1 then medlev=povinf;
else if age>0 then medlev=povkid;
else medlev=.;

*eligible if works 30 hrs. at min?  40 at min?;
el40m=(((minwage*160)/mpov)*100) < medlev;
el30m=(((minwage*120)/mpov)*100) < medlev;

proc means;
run;