log using c:\lara\papers\dynamic\child\duration\mar02\ERIU\kids\prepdata93.log,replace
# delimit;
set more off;
version 8.0;
*program to get just the variables needed for the models, and get them in a form
 that will be used in the regressions;
*need to start by getting the head data to be attached to the kids data;
*originally wanted to do highest earner, but head is easier;

set mem 1g;
use c:\lara\papers\dynamic\child\duration\mar02\ERIU\kids\all93;
keep mnum ppid hhaddi famid hgrad disab age relat empl;

gen hdhgrad=0;
replace hdhgrad=hgrad if relat==1;

gen hddisab=0;
replace hddisab=disab if relat==1;

gen hdage=0;
replace hdage=age if relat==1;

gen hdempl=0;
replace hdempl=empl if relat==1;

gen numearn=0;
replace numearn=1 if empl==1;

sum hdhgrad hddisab hdage hdempl numearn if relat==1;
*now collapse the data to get family-level;
collapse (sum) hdhgrad hddisab hdage hdempl numearn, by(mnum ppid hhaddi famid);
sum;

sort mnum ppid hhaddi famid;
save c:\lara\papers\dynamic\child\duration\mar02\ERIU\kids\headstuff93,replace;

*now use the main kids data;
drop _all;
set mem 300m;

use c:\lara\papers\dynamic\child\duration\mar02\ERIU\kids\newkids93;
*get rid of variables we definitely don't use, to save space;
drop smom nummths nmtot ppinc ppearn wavflg esr job* bus* mcare foodst empl nilf
 garec othwrec persafdc genasst othwelf gaimp othwimp allwel need pay upst mn mmn mneed
 mpay cpstate meth predict abbrev gross md* yw*;

*merge on the head stuff;
sort mnum ppid hhaddi famid;
merge mnum ppid hhaddi famid using  
c:\lara\papers\dynamic\child\duration\mar02\ERIU\kids\headstuff93;
tab _merge;
*_merge=1, from kids only, should be none of these;
assert _merge~=1;
*_merge=2, fams without kids;
drop if _merge==2;
drop _merge;

*merge on EITC data;
*get filing status for EITC merge;
gen filestat=1 if (famstr==0 | famstr==4 | famstr==6 | famstr==7);
replace filestat=2 if (famstr==2 | famstr==5);
replace filestat=3 if (famstr==1 | famstr==3);

*get number of kids in filing unit for EITC merge;
gen numkid=(numkids+ochrefgd);
replace numkid=3 if numkid>3;

*get 4-digit year for EITC merge;
gen year4=year+1900;

sort year4 state filestat numkid;
merge year4 state filestat numkid using c:\lara\papers\dynamic\Other_data\eicdata;
tab _merge;
*_merge=1 from 1993 data only, should be none of these;
assert _merge~=1;
*_merge=2 from EITC data only, years and states not in 1993 SIPP;
tab year4 if _merge==2;
sum state if _merge==2;
drop if _merge==2;
drop _merge soi abbrev filestat numkid;

*merge on health expenditure data;
sort state year4;
merge state year4 using c:\lara\papers\dynamic\Other_data\health_expend1;
tab _merge;
*_merge=1 from 1993 data only, should be none of these;
assert _merge~=1;
*_merge=2 from health data only, years and states not in 1993 SIPP;
tab year4 if _merge==2;
sum state if _merge==2;
drop if _merge==2;
drop _merge abbrev cpstate soi sname drugsall hospall physall perhospall perdrugsall perphysall;

*get the variables we need for the models in the form we need;
/*POLICY variables are medlev (Medicaid/SCHIP eligibility rules, as % of poverty line),*/
/*maxben (AFDC/TANF maximum benefit), carroti ("carrot" wavier implemented pre-TANF),*/
/*sticki ("stick" waiver implemented pre-TANF), tanf (dummy for TANF implemented),*/
/*maxeic (maximum EIC), eicphin (EIC initial phase-in rate)*/

gen afdcth=(maxben/mpov)*100;
sum afdcth medlev;
replace medlev=afdcth if medlev==0 & afdcth~=.;

*TANF not implemented in 1993 data;
gen tanf=0;

/*ECONOMIC conditions variables are unempr (state-level unemployment rate), minwage*/
/*(state-level minimum wage)*/

*make sure have right unemployment rate and minimum wage data;
sort state year month;
merge state year month using c:\lara\papers\Dynamic\other_data\min_une5;
tab _merge;
*_merge=1 from 1993 data, should be none of these;
assert _merge~=1;
*_merge=2 from other years, small states;
tab year smstate if _merge==2;
drop if _merge==2;
drop _merge abbrev smstate;

/*HEALTH market conditions variable is phcemed (Medicare expenditures on */
/*personal health care per enrollee in dollars)*/

/*DEMOGRAPHIC variables are age, male, black, othrace, hispanic, disab, immig, */
/*femhead (family is female-headed), othhead (family is neither female-headed nor 2-parent),*/
/*hdhgrad, hddisab, hdage, hdempl, oneearn, twoearn, numkids*/

gen male=(sex==1);
gen othrace=(race==3 | race==4);
gen oneearn=(numearn==1);
gen twoearn=(numearn>=2 & numearn~=.);

keep mnum priv mcaid first last ins trtype spell snum dur last_sp inscens sunique afdc 
 welfrint welcens welmonth weldur wel_ins rot ppid ppentry pppnum hhaddi famid birthday
 relat date state year4 fnlwt93 mpov mkreal intmon 
 medlev maxben carroti sticki mwimp tanf maxeic eicphin unempr minwage phcemed
 age male black othrace hispanic disab immig femhead othhead hdhgrad hddisab hdempl
 hdage oneearn twoearn numkids;

*identify the kids who have both Medicaid and private in any month, and drop all of 
 their observations;
gen both=(priv==1 & mcaid==1);
sum both;
tab priv mcaid;
sort sunique;
by sunique: egen anyboth=sum(both);
tab anyboth;
drop if anyboth>0;
drop anyboth both;

gen weight=fnlwt93;
drop fnlwt93;

compress;
aorder;
d;
sum;
save c:\lara\papers\dynamic\child\duration\mar02\ERIU\kids\keriu93,replace;
